@@ -103,7 +103,7 @@ void huge *zrealloc(void huge *p, long size, size_t old_size)
 	_fmemcpy(q, p, size < old_size ? size : old_size);
 	zfree(p);
 	return q;
-}
+} /* zrealloc */
 #endif /* __WATCOMC__ */
 
 
@@ -250,13 +250,13 @@ void init_header(void)
 	/* Claim to support Z-machine Standard 1.1. */
 	z_header.standard_high = 1;
 	z_header.standard_low = 1;
-}
+} /* init_header */
 
 
 void init_setup(void)
 {
 	memset(&f_setup, 0, sizeof(f_setup));
-	f_setup.undo_slots = MAX_UNDO_SLOTS;
+	f_setup.undo_slots = DEFAULT_UNDO_SLOTS;
 	f_setup.script_cols = 80;
 	f_setup.err_report_mode = ERR_DEFAULT_REPORT_MODE;
 	f_setup.blorb_file = NULL;
@@ -271,7 +271,7 @@ void init_setup(void)
 	f_setup.story_path = NULL;
 	f_setup.zcode_path = NULL;
 	f_setup.restricted_path = NULL;
-}
+} /* init_setup */
 
 
 /*
@@ -289,6 +289,7 @@ void init_memory(void)
 	zword addr;
 	unsigned n;
 	int i, j;
+	char errorstring[26]; /* Don't reuse this. */
 
 #ifdef TOPS20
 	zword checksum = 0;
@@ -458,6 +459,12 @@ void init_memory(void)
 	};
 	/* INDENT-ON */
 
+	/* Ensure undo slots don't exceed maximum */
+	if (f_setup.undo_slots > MAX_UNDO_SLOTS) {
+		sprintf(errorstring, "Maximum undo slots is %d", MAX_UNDO_SLOTS);
+		os_fatal(errorstring);
+	}
+
 	/* Open story file */
 	if ((story_fp = os_load_story()) == NULL)
 		os_fatal("Cannot open story file");
@@ -820,7 +827,9 @@ static void get_default_name(char *default_name, size_t length, zword addr)
  *	zargs[0] = address of area to restore (optional)
  *	zargs[1] = number of bytes to restore
  *	zargs[2] = address of suggested file name
- *
+ *      zargs[3] = 1 if frotz should ask for confirmation of filename
+ *		   0 if frotz should silently use provided filename
+ *		   default depends on interface
  */
 void z_restore(void)
 {
@@ -834,12 +843,22 @@ void z_restore(void)
 		/* Get the file name */
 		get_default_name(default_name, MAX_FILE_NAME + 1, (zargc >= 3) ? zargs[2] : 0);
 
-		new_name = os_read_file_name(default_name, FILE_LOAD_AUX);
-		if (new_name == NULL)
-			goto finished;
-
-		free(f_setup.aux_name);
-		f_setup.aux_name = strdup(default_name);
+		/* Do we have the fourth paramenter?
+		 * If the fourth paramenter is 0, skip to the else.
+		 * Otherwise, any value is equivalent to 1, do the first.
+		 * If no fourth parameter, give a prompt.
+		 */
+		if ((zargc >= 4) ? zargs[3] : 1) {
+			new_name = os_read_file_name(default_name, FILE_LOAD_AUX);
+			if (new_name == NULL)
+				goto finished;
+			free(f_setup.aux_name);
+			f_setup.aux_name = strdup(default_name);
+		} else {
+			new_name = os_read_file_name (default_name, FILE_NO_PROMPT);
+			if (new_name == NULL)
+				goto finished;
+		}
 
 		/* Open auxilary file */
 		if ((gfp = fopen (new_name, "rb")) == NULL)
@@ -1047,7 +1066,9 @@ void z_restore_undo(void)
  *	zargs[0] = address of memory area to save (optional)
  *	zargs[1] = number of bytes to save
  *	zargs[2] = address of suggested file name
- *
+ *      zargs[3] = 1 if frotz should ask for confirmation of filename
+ *		   0 if frotz should silently use provided filename
+ *		   default depends on interface
  */
 void z_save(void)
 {
@@ -1060,12 +1081,23 @@ void z_save(void)
 	if (zargc != 0) {
 		/* Get the file name */
 		get_default_name(default_name, MAX_FILE_NAME + 1, (zargc >= 3) ? zargs[2] : 0);
-		new_name = os_read_file_name(default_name, FILE_SAVE_AUX);
-		if (new_name == NULL)
-			goto finished;
 
-		free(f_setup.aux_name);
-		f_setup.aux_name = strdup(default_name);
+		/* Do we have the fourth paramenter?
+		 * If the fourth paramenter is 0, skip to the else.
+		 * Otherwise, any value is equivalent to 1, do the first.
+		 * If no fourth parameter, give a prompt.
+		 */
+		if ((zargc >= 4) ? zargs[3] : 1) {
+			new_name = os_read_file_name(default_name, FILE_SAVE_AUX);
+			if (new_name == NULL)
+				goto finished;
+			free(f_setup.aux_name);
+			f_setup.aux_name = strdup(default_name);
+		} else {
+			new_name = os_read_file_name (default_name, FILE_NO_PROMPT);
+			if (new_name == NULL)
+				goto finished;
+		}
 
 		/* Open auxilary file */
 		if ((gfp = fopen(new_name, "wb")) == NULL)
