@@ -101,10 +101,15 @@ typedef int bool;
 #define PATH_SEPARATOR '/'
 #endif
 
-/* typedef unsigned short zbyte; */
 typedef unsigned char zbyte;
 typedef unsigned short zword;
+
+#if defined(__TURBOC__) || defined(TOPS20)
 typedef unsigned long zlong;
+#else
+#include <stdint.h>
+typedef uint32_t zlong;
+#endif
 
 #ifndef USE_UTF8
 typedef unsigned char zchar;
@@ -170,6 +175,9 @@ typedef struct {
 #include "unused.h"
 
 /*** Constants that may be set at compile time ***/
+#ifndef DEFAULT_UNDO_SLOTS
+#define DEFAULT_UNDO_SLOTS 25
+#endif
 #ifndef MAX_UNDO_SLOTS
 #define MAX_UNDO_SLOTS 500
 #endif
@@ -197,9 +205,10 @@ extern const char build_timestamp[];
 #define EXT_BLORB4	".zblorb"
 #define EXT_COMMAND	".rec"
 #define EXT_AUX		".aux"
+#define EXT_LENGTH	7
 
 #ifndef DEFAULT_SAVE_NAME
-#define DEFAULT_SAVE_NAME "story.sav"
+#define DEFAULT_SAVE_NAME "story.qzl"
 #endif
 #ifndef DEFAULT_SCRIPT_NAME
 #define DEFAULT_SCRIPT_NAME "story.scr"
@@ -414,6 +423,7 @@ extern const char build_timestamp[];
 #define FILE_RECORD 4
 #define FILE_LOAD_AUX 5
 #define FILE_SAVE_AUX 6
+#define FILE_NO_PROMPT 7
 
 /*** Data access macros ***/
 #ifdef TOPS20
@@ -762,10 +772,11 @@ void 	z_window_size(void);
 void 	z_window_style(void);
 
 
-/* Definitions for error handling functions and error codes. */
-/* extern int err_report_mode; */
+/* Definitions and macros for error handling functions and error codes. */
 void	init_err(void);
-void	runtime_error(int);
+void	_runtime_error(int, bool);
+#define runtime_error_repeat(errnum)    _runtime_error(errnum, TRUE)
+#define runtime_error(errnum)           _runtime_error(errnum, FALSE)
 
 /* Error codes */
 #define ERR_TEXT_BUF_OVF 1	/* Text buffer overflow */
@@ -804,7 +815,9 @@ void	runtime_error(int);
 #define ERR_REMOVE_OBJECT_0 31	/* @remove_object called with object 0 */
 #define ERR_GET_NEXT_PROP_0 32	/* @get_next_prop called with object 0 */
 #define ERR_PLAY_SOUND 33	/* @play_sound called without SOUND_FLAG or OLD_SOUND_FLAG set */
-#define ERR_NUM_ERRORS (33)
+#define ERR_SOUND_MISSING 34	/* @play_sound called but picture resources are missing */
+#define ERR_PICTURE_MISSING 35	/* @draw_picture called but picture resources are missing */
+#define ERR_NUM_ERRORS (35)
 
 /*
  * There are four error reporting modes: never report errors;
@@ -879,7 +892,6 @@ void 	os_display_char(zchar);
 void 	os_display_string(const zchar *);
 void 	os_draw_picture(int, int, int);
 void 	os_erase_area(int, int, int, int, int);
-void 	os_fatal(const char *, ...);
 void 	os_finish_with_sample(int);
 int  	os_font_data(int, int *, int *);
 void 	os_init_screen(void);
@@ -902,6 +914,7 @@ int	os_from_true_colour(zword);
 void 	os_set_cursor(int, int);
 void 	os_set_font(int);
 void 	os_set_text_style(int);
+int	os_get_text_style(void);
 void 	os_start_sample(int, int, int, zword);
 void 	os_stop_sample(int);
 int	os_storyfile_seek(FILE *, long, int);
@@ -909,9 +922,15 @@ int	os_storyfile_tell(FILE *);
 int  	os_string_width(const zchar *);
 zword	os_to_true_colour (int);
 void	os_init_setup(void);
-void 	os_warn(const char *, ...);
 void	os_quit(int);
 
+/* Don't use string expansions from the core!  The dumb interface
+ * doesn't support it for historical reasons.  Suuport in the interfaces is
+ * optional.
+ */
+void 	os_fatal(const char *, ...);
+void 	os_warn(const char *, ...);
+
 /**
  * Called regularly by the interpreter, at least every few instructions
  * (only when interpreting: e.g., not when waiting for input).
