@@ -162,6 +162,11 @@ void z_read(void)
 	zbyte c;
 	int i;
 
+	if (f_setup.err_report_repeat > 0) {
+		runtime_error_repeat(f_setup.err_report_repeat);
+		f_setup.err_report_repeat = 0;
+	}
+
 	/* Supply default arguments */
 	if (zargc < 4)
 		zargs[3] = 0;
@@ -247,6 +252,12 @@ void z_read_char(void)
 {
 	zchar key;
 
+
+        if (f_setup.err_report_repeat > 0) {
+		runtime_error_repeat(f_setup.err_report_repeat);
+		f_setup.err_report_repeat = 0;
+	}
+
 	/* Supply default arguments */
 	if (zargc < 2)
 		zargs[1] = 0;
@@ -340,4 +351,4 @@ static bool truncate_question_mark(void)
 	if (story_id == SUSPECT) return TRUE;
 
 	return FALSE;
-}
+} /* truncate_question_mark */
