@@ -27,6 +27,7 @@ typedef struct frotz_setup_struct {
 	int ignore_errors;
 	int interpreter_number;
 	int piracy;
+	int tandy;
 	int undo_slots;
 	int expand_abbreviations;
 	int script_cols;
@@ -34,6 +35,7 @@ typedef struct frotz_setup_struct {
 	int quiet;
 	int bleep;
 	int err_report_mode;
+	int err_report_repeat;	/* If set, say it again at @zread() */
 
 	char *story_file;
 	char *blorb_file;
