@@ -184,8 +184,11 @@ void z_sound_effect(void)
 		return;
 	}
 
-	if (!f_setup.sound) {
+	if (!f_setup.sound)
 		runtime_error(ERR_PLAY_SOUND);
+
+	if (f_setup.blorb_file == NULL) {
+		runtime_error(ERR_SOUND_MISSING);
 		return;
 	}
 
@@ -235,5 +238,5 @@ void z_sound_effect(void)
 	if (number == 1 || number == 2)
 		os_beep(number);
 	return;
-}
+} /* z_sound_effect */
 #endif
