@@ -716,13 +716,13 @@ zchar os_read_line (int bufmax, zchar *buf, int timeout, int width,
 		int x2, max;
 		if (scrpos >= width)
 			scrpos = width - 1;
-			move(y, x + scrpos);
-			/* Maybe there's a cleaner way to do this,
-			 * but refresh() is  still needed here to
-			 * print spaces.  --DG
-			 */
-			refresh();
-			ch = unix_read_char(1);
+		move(y, x + scrpos);
+		/* Maybe there's a cleaner way to do this,
+		 * but refresh() is  still needed here to
+		 * print spaces.  --DG
+		 */
+		refresh();
+		ch = unix_read_char(1);
 		getyx(stdscr, y, x2);
 		x2++;
 		width = z_header.screen_width - margin;
@@ -970,13 +970,14 @@ zchar os_read_key (int timeout, int cursor)
  *
  * Return the name of a file.  Flag can be one of:
  *
- *    FILE_SAVE     - Save game file
- *    FILE_RESTORE  - Restore game file
- *    FILE_SCRIPT   - Transcript file
- *    FILE_RECORD   - Command file for recording
- *    FILE_PLAYBACK - Command file for playback
- *    FILE_SAVE_AUX - Save auxilary ("preferred settings") file
- *    FILE_LOAD_AUX - Load auxilary ("preferred settings") file
+ *    FILE_SAVE      - Save game file
+ *    FILE_RESTORE   - Restore game file
+ *    FILE_SCRIPT    - Transcript file
+ *    FILE_RECORD    - Command file for recording
+ *    FILE_PLAYBACK  - Command file for playback
+ *    FILE_SAVE_AUX  - Save auxilary ("preferred settings") file
+ *    FILE_LOAD_AUX  - Load auxilary ("preferred settings") file
+ *    FILE_NO_PROMPT - Return file without prompting the user
  *
  * The length of the file name is limited by MAX_FILE_NAME. Ideally
  * an interpreter should open a file requester to ask for the file
@@ -995,6 +996,7 @@ char *os_read_file_name (const char *default_name, int flag)
 	zchar answer[4];
 	char path_separator[2];
 	char file_name[FILENAME_MAX + 1];
+	char *ext;
 
 	path_separator[0] = PATH_SEPARATOR;
 	path_separator[1] = 0;
@@ -1006,7 +1008,7 @@ char *os_read_file_name (const char *default_name, int flag)
 	/* If we're restoring a game before the interpreter starts,
 	 * our filename is already provided.  Just go ahead silently.
 	 */
-	if (f_setup.restore_mode) {
+	if (f_setup.restore_mode || flag == FILE_NO_PROMPT) {
 		file_name[0]=0;
 	} else {
 		print_string ("Enter a file name.\nDefault is \"");
@@ -1051,7 +1053,7 @@ char *os_read_file_name (const char *default_name, int flag)
 		{
 			zchar z_name[FILENAME_MAX + 1];
 			zchar *zp;
-			read_string (FILENAME_MAX, z_name);
+			read_string (FILENAME_MAX - EXT_LENGTH, z_name);
 			i = 0;
 			zp = z_name;
 			while (*zp) {
@@ -1076,7 +1078,7 @@ char *os_read_file_name (const char *default_name, int flag)
 			file_name[i] = 0;
 		}
 #else
-		read_string (FILENAME_MAX, (zchar *)file_name);
+		read_string (FILENAME_MAX - EXT_LENGTH, (zchar *)file_name);
 #endif
 	}
 
@@ -1091,8 +1093,17 @@ char *os_read_file_name (const char *default_name, int flag)
 	}
 
 	/* Use the default name if nothing was typed */
-	if (file_name[0] == 0)
-		strncpy (file_name, default_name, FILENAME_MAX);
+	if (file_name[0] == 0) {
+		/* If FILE_NO_PROMPT, restrict to currect directory. */
+		/* If FILE_NO_PROMPT and using restricted path, then */
+		/*   nothing more needs to be done to restrict the   */
+		/*   file access there. */
+		if (flag == FILE_NO_PROMPT && f_setup.restricted_path == NULL) {
+			tempname = basename((char *)default_name);
+			strncpy(file_name, tempname, FILENAME_MAX);
+		} else
+			strncpy (file_name, default_name, FILENAME_MAX);
+	}
 
 	/* If we're restricted to one directory, strip any leading path left
 	 * over from a previous call to os_read_file_name(), then prepend
@@ -1117,6 +1128,33 @@ char *os_read_file_name (const char *default_name, int flag)
 		strncat(file_name, tempname, strlen(file_name) - strlen(tempname) - 1);
 	}
 
+	ext = strrchr(file_name, '.');
+	if (flag == FILE_NO_PROMPT) {
+		if (strncmp(ext, EXT_AUX, 4)) {
+			os_warn("Blocked unprompted access of %s. Should only be %s files.", file_name, EXT_AUX);
+			return NULL;
+		}
+	}
+
+	/* Add appropriate filename extensions if not already there. */
+	if (flag == FILE_SAVE || flag == FILE_RESTORE) {
+		if (ext == NULL || strncmp(ext, EXT_SAVE, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_SAVE, EXT_LENGTH);
+		}
+	} else if (flag == FILE_SCRIPT) {
+		if (ext == NULL || strncmp(ext, EXT_SCRIPT, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_SCRIPT, EXT_LENGTH);
+		}
+	} else if (flag == FILE_SAVE_AUX || flag == FILE_LOAD_AUX) {
+		 if (ext == NULL || strncmp(ext, EXT_AUX, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_AUX, EXT_LENGTH);
+		}
+	} else if (flag == FILE_RECORD || flag == FILE_PLAYBACK) {
+		if (ext == NULL || strncmp(ext, EXT_COMMAND, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_COMMAND, EXT_LENGTH);
+		}
+	}
+
 	/* Warn if overwriting a file. */
 	if ((flag == FILE_SAVE || flag == FILE_SAVE_AUX ||
 	    flag == FILE_RECORD || flag == FILE_SCRIPT)
