@@ -158,6 +158,22 @@ void os_set_colour (int new_foreground, int new_background)
 } /* os_set_colour */
 
 
+/*
+ * os_get_text_style
+ *
+ * Return the current text style.  Following flags can be set:
+ *
+ *     REVERSE_STYLE
+ *     BOLDFACE_STYLE
+ *     EMPHASIS_STYLE (aka underline aka italics)
+ *     FIXED_WIDTH_STYLE
+ *
+ */
+int os_get_text_style (void)
+{
+	return u_setup.current_text_style;
+} /* os_get_text_style */
+
 /*
  * os_set_text_style
  *
@@ -306,7 +322,7 @@ int os_check_unicode(int UNUSED(font), zchar UNUSED(c))
 {
 	/* Assume full input and output.  */
 	return 3;
-}
+} /* os_check_unicode */
 
 
 /*
