@@ -22,6 +22,7 @@
 #include <conio.h>
 #include <dos.h>
 #include <stdio.h>
+#include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include "frotz.h"
@@ -83,7 +84,6 @@ int user_reverse_bg = -1;
 int user_reverse_fg = -1;
 int user_screen_height = -1;
 int user_screen_width = -1;
-int user_tandy_bit = -1;
 int user_random_seed = -1;
 int user_font = 1;
 
@@ -103,7 +103,8 @@ static bool test_enhanced_keyboard(unsigned char b)
 	regs.h.ah = 0x12;
 	int86(0x16, &regs, &regs);
 	return b == regs.h.al;
-}
+} /* test_enhanced_keyboard */
+
 
 /*
  * os_init_setup
@@ -236,7 +237,46 @@ void os_quit(int status)
 {
     cleanup();
     exit(status);
-}
+} /* os_quit */
+
+
+static void print_c_string (const char *s)
+{
+	zchar c;
+
+	while ((c = *s++) != 0)
+		os_display_char (c);
+} /* print_c_string */
+
+
+/*
+ * os_warn
+ *
+ * Display a warning message and continue with the game.
+ *
+ */
+void os_warn (const char *s, ...)
+{
+	va_list m;
+	char errorstring[81];
+	int style;
+
+	va_start(m, s);
+	vsprintf(errorstring, s, m);
+	va_end(m);
+
+	os_beep(BEEP_HIGH);
+	style = os_get_text_style();
+	os_set_text_style(BOLDFACE_STYLE);
+	print_c_string("Warning: ");
+	os_set_text_style(NORMAL_STYLE);
+	print_c_string(errorstring);
+	new_line();
+	os_set_text_style(style);
+
+	return;
+} /* os_warn */
+
 
 /*
  * os_fatal
@@ -330,7 +370,7 @@ static void parse_options(int argc, char **argv)
 		if (c == 'S')
 			f_setup.script_cols = num;
 		if (c == 't')
-			user_tandy_bit = 1;
+			f_setup.tandy = 1;
 		if (c == 'u')
 			f_setup.undo_slots = num;
 		if (c == 'v') {
@@ -339,7 +379,7 @@ static void parse_options(int argc, char **argv)
 			printf("Git commit:     %s\n", GIT_HASH);
 			printf("Notes:          %s\n", RELEASE_NOTES);
 			printf("  Frotz was originally written by Stefan Jokisch.\n");
-			printf("  It complies with standard 1.0 of Graham Nelson's specification.\n");
+			printf("  It complies with standard 1.1 of the Z-Machine Standard.\n");
 			printf("  It was ported to Unix by Galen Hazelwood.\n");
 			printf("  The core and DOS port are maintained by David Griffith.\n");
 			printf("  Frotz's homepage is https://661.org/proj/if/frotz/\n");
@@ -359,17 +399,18 @@ static void parse_options(int argc, char **argv)
 
 } /* parse_options */
 
+
 static char *malloc_filename(char *story_name, char *extension)
 {
 	int length = strlen(story_name) + strlen(extension) + 2;
 	char *filename = malloc(length);
 	if (filename) {
 		strcpy(filename, story_name);
-		strcat(filename, ".");
 		strcat(filename, extension);
 	}
 	return filename;
-}
+} /* malloc_filename */
+
 
 /*
  * os_process_arguments
@@ -432,10 +473,10 @@ void os_process_arguments(int argc, char *argv[])
 	f_setup.story_name = strdup(stripped_story_name);
 
 	/* Create nice default file names */
-	f_setup.script_name = malloc_filename(f_setup.story_name, "scr");
-	f_setup.command_name = malloc_filename(f_setup.story_name, "rec");
-	f_setup.save_name = malloc_filename(f_setup.story_name, "sav");
-	f_setup.aux_name = malloc_filename(f_setup.story_name, "aux");
+	f_setup.script_name = malloc_filename(f_setup.story_name, EXT_SCRIPT);
+	f_setup.command_name = malloc_filename(f_setup.story_name, EXT_COMMAND);
+	f_setup.save_name = malloc_filename(f_setup.story_name, EXT_SAVE);
+	f_setup.aux_name = malloc_filename(f_setup.story_name, EXT_AUX);
 
 	/* Save the executable file name */
 	progname = argv[0];
@@ -484,7 +525,8 @@ static void standard_palette(void)
  * Set palette register #i to value i and call VGA BIOS to use DAC
  * registers #64 to #127.
  *
- */ static void special_palette(void)
+ */
+static void special_palette(void)
 {
 
 	static byte palette[] = {
@@ -537,7 +579,8 @@ static void standard_palette(void)
  * Finally, set reserve_mem to the amount of memory (in bytes) that
  * should not be used for multiple undo and reserved for later use.
  *
- */ void os_init_screen(void)
+ */
+void os_init_screen(void)
 {
 	static byte zcolour[] = {
 		BLACK_COLOUR,
@@ -711,7 +754,7 @@ static void standard_palette(void)
 
 	/* Set various bits in the configuration byte. These bits tell
 	   the game which features are supported by the interpreter. */
-	if (z_header.version == V3 && user_tandy_bit != -1)
+	if (z_header.version == V3 && f_setup.tandy != -1)
 		z_header.config |= CONFIG_TANDY;
 	if (z_header.version == V3)
 		z_header.config |= CONFIG_SPLITSCREEN;
@@ -963,7 +1006,7 @@ FILE *os_load_story(void)
 #else
 	return fopen(f_setup.story_file, "rb");
 #endif
-}
+} /* os_load_story */
 
 
 /*
@@ -991,7 +1034,7 @@ int os_storyfile_seek(FILE * fp, long offset, int whence)
 	}
 #endif
 	return fseek(fp, offset, whence);
-}
+} /* os_storyfile_seek */
 
 
 /*
@@ -1006,4 +1049,4 @@ int os_storyfile_tell(FILE * fp)
 		return ftell(fp) - blorb_res.data.startpos;
 #endif
 	return ftell(fp);
-}
+} /* os_storyfile_tell */
