@@ -89,6 +89,7 @@ static byte _far *graphics_font = NULL;
 
 static char name[] = "FONTS/FONT0.FNT";
 
+
 /*
  * available_bios
  *
@@ -131,8 +132,8 @@ static int available_bios(void)
 	label_ret:
 	return (_AX);
 #endif
+} /* available_bios */
 
-}
 
 /*
  * set_user_tfont
@@ -159,7 +160,8 @@ static void set_user_tfont(word offset, byte height)
 		int 10h
 		pop bp
 	}
-}
+} /* set_user */
+
 
 /*
  * set_user_gfont
@@ -184,7 +186,8 @@ static void set_user_gfont(word offset, word height)
 		int 10h
 		pop bp
 	}
-}
+} /* set_user_gfont */
+
 
 /*
  * read_font
@@ -202,7 +205,8 @@ static void read_font(word offset, size_t nmemb)
 		fread(font_data+offset, 1, nmemb, fp);
 		fclose(fp);
 	}
-}
+} /* read_font */
+
 
 /*
  * load_fonts
@@ -491,10 +495,26 @@ void os_set_colour(int new_foreground, int new_background)
 
 	/* Apply changes */
 	adjust_style();
-
 } /* os_set_colour */
 
 
+/*
+ * os_get_text_style
+ *
+ * Return the current text style.  Following flags can be set:
+ *
+ *     REVERSE_STYLE
+ *     BOLDFACE_STYLE
+ *     EMPHASIS_STYLE (aka underline aka italics)
+ *     FIXED_WIDTH_STYLE
+ *
+ */
+int os_get_text_style (void)
+{
+	return current_style;
+} /* os_get_text_style */
+
+
 /*
  * os_set_text_style
  *
@@ -512,7 +532,6 @@ void os_set_text_style(int new_style)
 
 	/* Apply changes */
 	adjust_style();
-
 } /* os_set_text_style */
 
 
@@ -589,7 +608,8 @@ void write_pattern(volatile byte _far * screen, byte val, byte mask)
  * indentation). The screen should not be scrolled after printing to the
  * bottom right corner.
  *
- */ void os_display_char(zchar c)
+ */
+void os_display_char(zchar c)
 {
 	int width = os_char_width(c);
 
@@ -979,7 +999,8 @@ int os_from_true_colour(zword colour)
 	}
 #endif
 	return 0;
-}
+} /* os_from_true_colour */
+
 
 /*
  * os_to_true_colour
@@ -1011,4 +1032,4 @@ zword os_to_true_colour(int index)
 #else
 	return 0;
 #endif
-}
+} /* os_to_true_colour */
