@@ -104,7 +104,7 @@ static int xgetchar(void)
 #endif
 	}
 	return c;
-}
+} /* xgetchar */
 
 
 /* Read one line, including the newline, into s.  Safely avoids buffer
@@ -125,7 +125,7 @@ static void dumb_getline(char *s)
 	while ((c = xgetchar()) != '\n')
 		;
 	printf("Line too long, truncated to %s\n", s - INPUT_BUFFER_SIZE);
-}
+} /* dumb_getline */
 
 
 /* Translate in place all the escape characters in s.  */
@@ -175,7 +175,7 @@ static void translate_special_chars(char *s)
 			}
 		}
 	*dest = '\0';
-}
+} /* translate_special_chars */
 
 
 /* The time in tenths of seconds that the user is ahead of z time.  */
@@ -192,14 +192,14 @@ static bool check_timeout(int timeout)
 	else
 		time_ahead -= timeout;
 	return time_ahead != 0;
-}
+} /* check_timeout */
 
 
 /* If val is '0' or '1', set *var accordingly, otherwise toggle it.  */
 static void toggle(bool *var, char val)
 {
 	*var = val == '1' || (val != '0' && !*var);
-}
+} /* toggle */
 
 
 /* Handle input-related user settings and call dumb_output_handle_setting.  */
@@ -220,7 +220,7 @@ bool dumb_handle_setting(const char *setting, bool show_cursor, bool startup)
 		return dumb_output_handle_setting(setting, show_cursor, startup);
 	}
 	return TRUE;
-}
+} /* dumb_handle_setting */
 
 
 /* Read a line, processing commands (lines that start with a backslash
@@ -330,7 +330,7 @@ static bool dumb_read_line(char *s, char *prompt, bool show_cursor,
 			fprintf(stderr, "Enter \\help to see the list of commands\n");
 		}
 	}
-}
+} /* dumb_read_line */
 
 
 /* Read a line that is not part of z-machine input (more prompts and
@@ -340,7 +340,7 @@ static void dumb_read_misc_line(char *s, char *prompt)
 	dumb_read_line(s, prompt, 0, 0, 0, 0);
 	/* Remove terminating newline */
 	s[strlen(s) - 1] = '\0';
-}
+} /* dumb_read_misc_line */
 
 
 /* For allowing the user to input in a single line keys to be returned
@@ -382,7 +382,7 @@ error:
 	}
 	*out = ch;
 	return idx;
-}
+} /* utf8_to_zchar */
 #endif
 
 
@@ -420,7 +420,7 @@ zchar os_read_key (int timeout, bool show_cursor)
 	/* TODO: error messages for invalid special chars.  */
 
 	return c;
-}
+} /* os_read_key */
 
 
 zchar os_read_line (int UNUSED (max), zchar *buf, int timeout, int UNUSED(width), int continued)
@@ -494,9 +494,30 @@ zchar os_read_line (int UNUSED (max), zchar *buf, int timeout, int UNUSED(width)
 
 	timed_out_last_time = FALSE;
 	return terminator;
-}
+} /* os_read_line */
 
 
+/*
+ * os_read_file_name
+ *
+ * Return the name of a file. Flag can be one of:
+ *
+ *    FILE_SAVE      - Save game file
+ *    FILE_RESTORE   - Restore game file
+ *    FILE_SCRIPT    - Transcript file
+ *    FILE_RECORD    - Command file for recording
+ *    FILE_PLAYBACK  - Command file for playback
+ *    FILE_SAVE_AUX  - Save auxilary ("preferred settings") file
+ *    FILE_LOAD_AUX  - Load auxilary ("preferred settings") file
+ *    FILE_NO_PROMPT - Return file without prompting the user
+ *
+ * The length of the file name is limited by MAX_FILE_NAME. Ideally
+ * an interpreter should open a file requester to ask for the file
+ * name. If it is unable to do that then this function should call
+ * print_string and read_string to ask for a file name.
+ *
+ * Return value is NULL if there was a problem.
+ */
 char *os_read_file_name (const char *default_name, int flag)
 {
 	char file_name[FILENAME_MAX + 1];
@@ -509,6 +530,7 @@ char *os_read_file_name (const char *default_name, int flag)
 	char *tempname;
 	char path_separator[2];
 	int i;
+	char *ext;
 
 	path_separator[0] = PATH_SEPARATOR;
 	path_separator[1] = 0;
@@ -518,33 +540,39 @@ char *os_read_file_name (const char *default_name, int flag)
 	 */
 	if (f_setup.restore_mode) {
 		return strdup(default_name);
+	} else if (flag == FILE_NO_PROMPT) {
+		ext = strrchr(default_name, '.');
+		if (strncmp(ext, EXT_AUX, 4)) {
+			os_warn("Blocked unprompted access of %s. Should only be %s files.", default_name, EXT_AUX);
+			free(ext);
+			return NULL;
+		}
+		free(ext);
+		if (f_setup.restricted_path == NULL)
+			buf = strndup(default_name, MAX_FILE_NAME - EXT_LENGTH);
+		else
+			buf = basename((char *)default_name);
 	} else {
-		if (f_setup.restricted_path) {
-			for (i = strlen(default_name); i > 0; i--) {
-				if (default_name[i] == PATH_SEPARATOR) {
-					i++;
-					break;
-				}
-			}
-			tempname = strdup(default_name + i);
-			sprintf(prompt, "Please enter a filename [%s]: ", tempname);
+		if (f_setup.restricted_path != NULL) {
+			sprintf(prompt, "Please enter a filename [%s]: ", basename((char *)default_name));
 		} else
 			sprintf(prompt, "Please enter a filename [%s]: ", default_name);
+
 		dumb_read_misc_line(fullpath, prompt);
-		if (!fullpath[0])
-			buf = fullpath;
-		else
-			buf = basename(fullpath);
+
+		/* If using default filename... */
+		if (strlen(fullpath) == 0)
+			buf = strndup(default_name, MAX_FILE_NAME);
+		else /* Using supplied filename... */
+			buf = strndup(fullpath, MAX_FILE_NAME);
+
 		if (strlen(buf) > MAX_FILE_NAME) {
 			printf("Filename too long\n");
 			return NULL;
 		}
 	}
 
-	if (buf[0])
-		strncpy(file_name, fullpath, FILENAME_MAX);
-	else
-		strncpy(file_name, default_name, FILENAME_MAX);
+	strncpy(file_name, buf, FILENAME_MAX);
 
 	/* Check if we're restricted to one directory. */
 	if (f_setup.restricted_path != NULL) {
@@ -564,6 +592,26 @@ char *os_read_file_name (const char *default_name, int flag)
 		strncat(file_name, tempname, strlen(file_name) - strlen(tempname) - 1);
 	}
 
+	/* Add appropriate filename extensions if not already there. */
+	ext = strrchr(file_name, '.');
+	if (flag == FILE_SAVE || flag == FILE_RESTORE) {
+		if (ext == NULL || strncmp(ext, EXT_SAVE, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_SAVE, EXT_LENGTH);
+		}
+	} else if (flag == FILE_SCRIPT) {
+		if (ext == NULL || strncmp(ext, EXT_SCRIPT, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_SCRIPT, EXT_LENGTH);
+		}
+	} else if (flag == FILE_SAVE_AUX || flag == FILE_LOAD_AUX) {
+		if (ext == NULL || strncmp(ext, EXT_AUX, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_AUX, EXT_LENGTH);
+		}
+	} else if (flag == FILE_RECORD || flag == FILE_PLAYBACK) {
+		if (ext == NULL || strncmp(ext, EXT_COMMAND, EXT_LENGTH) != 0) {
+			strncat(file_name, EXT_COMMAND, EXT_LENGTH);
+		}
+	}
+
 	/* Warn if overwriting a file.  */
 	if ((flag == FILE_SAVE || flag == FILE_SAVE_AUX || flag == FILE_RECORD)
 		&& ((fp = fopen(file_name, "rb")) != NULL)) {
@@ -573,7 +621,7 @@ char *os_read_file_name (const char *default_name, int flag)
 			return NULL;
 	}
 	return strdup(file_name);
-}
+} /* os_read_file_name */
 
 
 void os_more_prompt (void)
@@ -583,7 +631,7 @@ void os_more_prompt (void)
 		dumb_read_misc_line(buf, "***MORE***");
 	} else
 		dumb_elide_more_prompt();
-}
+} /* os_more_prompt */
 
 
 void dumb_init_input(void)
@@ -593,16 +641,16 @@ void dumb_init_input(void)
 
 	if (z_header.version >= V5)
 		z_header.flags &= ~(MOUSE_FLAG | MENU_FLAG);
-}
+} /* dumb_init_input */
 
 
 zword os_read_mouse(void)
 {
 	/* NOT IMPLEMENTED */
 	return 0;
-}
+} /* os_read_mouse */
 
-void os_tick()
+void os_tick(void)
 {
 	/* Nothing here yet */
-}
+} /* os_tick */
