@@ -47,7 +47,7 @@ static int round_div(int x, int y)
 	if ((dblremain > y) || ((dblremain == y) && (quotient & 1)))
 		quotient++;
 	return quotient;
-}
+} /* round_div */
 #endif /* NO_BLORB */
 
 
@@ -157,7 +157,7 @@ bool dumb_init_pictures (void)
 #else
 	return FALSE;
 #endif
-}
+} /* dumb_init_pictures */
 
 
 /* Convert a Z picture number to an index into pict_info.  */
@@ -165,12 +165,14 @@ bool dumb_init_pictures (void)
 static int z_num_to_index(int n)
 {
 	int i;
+	if (pict_info == NULL)
+		return -1;
 	for (i = 0; i <= num_pictures; i++) {
 		if (pict_info[i].z_num == n)
 			return i;
 	}
 	return -1;
-}
+} /* z_num_to_index */
 #endif
 
 
@@ -182,7 +184,7 @@ bool os_picture_data(int num, int *height, int *width)
 	*height = 0;
 	*width = 0;
 
-	if (!pict_info)
+	if (pict_info == NULL || !pict_info)
 		return FALSE;
 
 	if ((index = z_num_to_index(num)) == -1)
@@ -192,7 +194,7 @@ bool os_picture_data(int num, int *height, int *width)
 	*width = pict_info[index].width;
 #endif
 	return TRUE;
-}
+} /* os_picture_data */
 
 
 void os_draw_picture (int num, int row, int col)
@@ -227,7 +229,7 @@ void os_draw_picture (int num, int row, int col)
 			dumb_set_picture_cell(row + height - 2, c, num ? (num % 10 + '0') : ':');
 	}
 #endif
-}
+} /* os_draw_picture */
 
 
 int os_peek_colour (void) {return BLACK_COLOUR; }
