@@ -30,8 +30,8 @@
 
 typedef struct {
 	int refcount;
-	word minchar, maxchar, defchar;
-	byte ascent, descent;
+	zword minchar, maxchar, defchar;
+	zbyte ascent, descent;
 	int glyphs[0];		/* offsets to glyphs from start of rec */
 } SF_bdffont;
 
@@ -64,7 +64,7 @@ static int hexd(char c)
 }
 
 
-static void gethex(char *p, byte * dst, int n)
+static void gethex(char *p, zbyte * dst, int n)
 {
 	while (n--) {
 		*dst++ = 16 * hexd(p[0]) + hexd(p[1]);
@@ -78,7 +78,7 @@ static void gethex(char *p, byte * dst, int n)
 static SF_bdffont *sBDXload(FILE * f, int *err, int *size, int MAXCHAR)
 {
 	int totb, i, k = 0, wh[4];
-	byte *po, *pbeg;
+	zbyte *po, *pbeg;
 	char *p, *q;
 	char *fontname = "", *copyright = "unknown";
 	int fngot = 0, cpgot = 0;
@@ -197,8 +197,8 @@ static SF_bdffont *sBDXload(FILE * f, int *err, int *size, int MAXCHAR)
 	font->defchar = defchar;
 	font->ascent = ascent;
 	font->descent = descent;
-	pbeg = (byte *) font;
-	po = (byte *) (&(font->glyphs[maxch - minch + 1]));
+	pbeg = (zbyte *) font;
+	po = (zbyte *) (&(font->glyphs[maxch - minch + 1]));
 	k = strlen(fontname) + 1;
 	memmove(po, fontname, k);
 	po += k;
@@ -259,7 +259,7 @@ static SF_bdffont *sBDXload(FILE * f, int *err, int *size, int MAXCHAR)
 				bg->h = h = wh[1];
 				bg->xof = wh[2];
 				bg->yof = wh[3];
-				po = (byte *) (&(bg->bitmap[0]));
+				po = (zbyte *) (&(bg->bitmap[0]));
 				for (j = 0; j < h; j++) {
 					fgets(s, 1024, f);
 					if (feof(f))
@@ -336,7 +336,7 @@ static int bmaxchar(SFONT * s)
 	return 0;
 }
 
-static SF_glyph *getglyph(SFONT * fo, word c, int allowdef)
+static SF_glyph *getglyph(SFONT * fo, zword c, int allowdef)
 {
 	int m;
 	SF_bdffont *b;
@@ -358,11 +358,11 @@ static SF_glyph *getglyph(SFONT * fo, word c, int allowdef)
 		else
 			return NULL;
 	}
-	return (SF_glyph *) (((byte *) b) + m);
+	return (SF_glyph *) (((zbyte *) b) + m);
 }
 
 
-static int hasglyph(SFONT * fo, word c, int allowdef)
+static int hasglyph(SFONT * fo, zword c, int allowdef)
 {
 	return (getglyph(fo, c, allowdef) != NULL);
 }
@@ -483,7 +483,7 @@ static void setfontk(int k, SFONT * f)
 }
 
 
-static void cleanfonts()
+static void cleanfonts(void)
 {
 	int i;
 	for (i = 0; i < 8; i++)
@@ -493,13 +493,13 @@ static void cleanfonts()
 }
 
 
-SF_textsetting *sf_curtextsetting()
+SF_textsetting *sf_curtextsetting(void)
 {
 	return &current;
 }
 
 
-void sf_pushtextsettings()
+void sf_pushtextsettings(void)
 {
 	if (tsstackptr < MAXSTACK) {
 		tsstack[tsstackptr] = current;
@@ -508,7 +508,7 @@ void sf_pushtextsettings()
 }
 
 
-void sf_poptextsettings()
+void sf_poptextsettings(void)
 {
 	if (tsstackptr) {
 		tsstackptr--;
@@ -525,7 +525,7 @@ void sf_poptextsettings()
  *
  *
  */
-int os_check_unicode(int font, zchar c)
+int os_check_unicode(int UNUSED (font), zchar c)
 {
 	return ((current.font->hasglyph(current.font, c, 0) != 0) ? 3 : 2);
 }
@@ -635,6 +635,23 @@ void os_set_font(int new_font)
 }
 
 
+/*
+ * os_get_text_style
+ *
+ * Return the current text style.  Following flags can be set:
+ *
+ *     REVERSE_STYLE
+ *     BOLDFACE_STYLE
+ *     EMPHASIS_STYLE (aka underline aka italics)
+ *     FIXED_WIDTH_STYLE
+ *
+ */
+int os_get_text_style (void)
+{
+	return current.style;
+} /* os_get_text_style */
+
+
 /*
  * os_set_text_style
  *
@@ -733,7 +750,6 @@ void os_display_char(zchar c)
 		g = current.font->getglyph(current.font, c, 1);
 		if (g) {
 			sf_writeglyph(g);
-			m_exitPause = true;
 		}
 	}
 }
@@ -763,7 +779,7 @@ int os_buffer_screen(int mode)
  * Return non-zero if the window should have text wrapped.
  *
  */
-int os_wrap_window(int win)
+int os_wrap_window(int UNUSED (win))
 {
 	return 1;
 }
@@ -775,8 +791,9 @@ int os_wrap_window(int win)
  * Called when the height of a window is changed.
  *
  */
-void os_window_height(int win, int height)
+void os_window_height(int UNUSED (win), int UNUSED (height))
 {
+	/* Not implemented */
 }
 
 
@@ -851,10 +868,10 @@ SFONT *sf_VGA_SFONT;
 
 
 /* ensure a font loaded */
-void sf_initfonts()
+void sf_initfonts(void)
 {
 	int i, j, size = 0;
-	byte *cfont, *bmp;
+	zbyte *cfont, *bmp;
 	SF_glyph *g;
 	SF_bdffont *norm, *emph, *bold, *bemp;
 	SFONT *Norm, *Emph = NULL, *Bold = NULL, *Bemp = NULL;
@@ -877,13 +894,13 @@ void sf_initfonts()
 		os_fatal("malloc() failure in initfonts()");
 	memmove(emph, norm, size);
 	/* emphasize (underline)... */
-	cfont = (byte *) emph;
+	cfont = (zbyte *) emph;
 	for (i = norm->minchar; i <= norm->maxchar; i++) {
 		int m = norm->glyphs[i - norm->minchar];
 		if (!m)
 			continue;
 		g = (SF_glyph *) (cfont + m);
-		bmp = (byte *) (&(g->bitmap[0]));
+		bmp = (zbyte *) (&(g->bitmap[0]));
 		bmp[g->h - 2] = 0xff;
 	}
 	/* make a copy for bold */
@@ -895,14 +912,14 @@ void sf_initfonts()
 		os_fatal("malloc() failure in initfonts()");
 	memmove(bold, norm, size);
 	/* boldify... */
-	cfont = (byte *) bold;
+	cfont = (zbyte *) bold;
 	for (i = norm->minchar; i <= norm->maxchar; i++) {
 		int h, m = norm->glyphs[i - norm->minchar];
 		if (!m)
 			continue;
 		g = (SF_glyph *) (cfont + m);
 		h = g->h;
-		bmp = (byte *) (&(g->bitmap[0]));
+		bmp = (zbyte *) (&(g->bitmap[0]));
 		for (j = 0; j < h; j++) {
 			int c = bmp[j];
 			bmp[j] = (c) | (c >> 1);
@@ -917,13 +934,13 @@ void sf_initfonts()
 		os_fatal("malloc() failure in initfonts()");
 	memmove(bemp, bold, size);
 	/* emphasize (underline)... */
-	cfont = (byte *) bemp;
+	cfont = (zbyte *) bemp;
 	for (i = norm->minchar; i <= norm->maxchar; i++) {
 		int m = norm->glyphs[i - norm->minchar];
 		if (!m)
 			continue;
 		g = (SF_glyph *) (cfont + m);
-		bmp = (byte *) (&(g->bitmap[0]));
+		bmp = (zbyte *) (&(g->bitmap[0]));
 		bmp[g->h - 2] = 0xff;
 	}
 
