@@ -46,17 +46,15 @@ extern FILE *blorb_fp;
 
 
 /* various data */
-bool m_tandy = 0;
 int m_v6scale_x;
 int m_v6scale_y;
 double m_gfxScale_w = 1.0;
 double m_gfxScale_h = 1.0;
-ulong m_defaultFore;
-ulong m_defaultBack;
-ulong m_colours[11];
-ulong m_nonStdColours[NON_STD_COLS];
+zlong m_defaultFore;
+zlong m_defaultBack;
+zlong m_colours[11];
+zlong m_nonStdColours[NON_STD_COLS];
 int m_nonStdIndex;
-bool m_exitPause = 0;
 bool m_lineInput = 0;
 bool m_IsInfocomV6 = false;
 bool m_morePrompts = 1;
@@ -86,7 +84,7 @@ bool m_adaptiveMode = FALSE;
 
 bb_resolution_t *reso;
 
-static void checkwidths()
+static void checkwidths(void)
 {
 	reso = bb_get_resolution(blorb_map);
 	if (reso) {
@@ -96,7 +94,7 @@ static void checkwidths()
 		if ((reso->py) && (reso->py >= AcHeight))
 			AcHeight = reso->py;
 	}
-}
+} /* checkwidths */
 
 
 static void sf_cleanup_resources(void)
@@ -107,7 +105,7 @@ static void sf_cleanup_resources(void)
 	if (blorb_fp)
 		fclose(blorb_fp);
 	blorb_fp = NULL;
-}
+} /* sf_cleanup_resources */
 
 static void load_local_resources(void);
 
@@ -142,7 +140,7 @@ int sf_load_resources(void)
 		load_local_resources();
 
 	return 0;
-}
+} /* sf_load_resources */
 
 
 /*
@@ -218,7 +216,7 @@ FILE *os_path_open(const char *name, const char *mode)
 		return fp;
 	}
 	return NULL;	/* give up */
-} /* os_path_open() */
+} /* os_path_open */
 
 
 /*
@@ -250,7 +248,7 @@ int os_picture_data(int picture, int *height, int *width)
 	*height = 0;
 	*width = 0;
 	return 0;
-}
+} /* os_picture_data */
 
 
 /*
@@ -262,7 +260,7 @@ int os_picture_data(int picture, int *height, int *width)
  *     MENU_REMOVE - Remove the menu at the given index
  *
  */
-void os_menu(int action, int menu, const zword * text)
+void os_menu(int UNUSED (action), int UNUSED (menu), const zword * UNUSED (text))
 {
 /*	switch (action)
 	{
@@ -276,7 +274,7 @@ void os_menu(int action, int menu, const zword * text)
 		theWnd->RemoveMenu(menu);
 		break;
 	}*/
-}
+} /* os_menu */
 
 
 /*
@@ -294,7 +292,7 @@ int os_random_seed(void)
 		return ((int)(time(NULL))) & 32767;
 	}
 	return m_random_seed;
-}
+} /* os_random_seed */
 
 
 /* The following assumes Unicode */
@@ -322,7 +320,7 @@ void os_scrollback_char(zword c)
 			putchar(0x80 + (c & 0x3f));
 		}
 	}
-}
+} /* os_scrollback_char */
 
 
 /*
@@ -336,7 +334,7 @@ void os_scrollback_erase(int erase)
 	if (option_scrollback_buffer)
 		while (erase--)
 			putchar(8);
-}
+} /* os_scrollback_erase */
 
 
 /*
@@ -361,13 +359,13 @@ void os_restart_game(int stage)
 			sf_read_key(0, false, false, false);
 		}
 	}
-}
+} /* os_restart_game */
 
 
 #define DEFAULT_GAMMA 2.2
 double m_gamma = DEFAULT_GAMMA;
 
-void sf_initcolours()
+void sf_initcolours(void)
 {
 	int i;
 
@@ -390,7 +388,7 @@ void sf_initcolours()
 		m_nonStdColours[i] = 0xFFFFFFFF;
 	m_nonStdIndex = 0;
 
-}
+} /* sf_initcolours */
 
 
 /* Read in settings */
@@ -425,7 +423,7 @@ void sf_readsettings(void)
 	    sf_GetProfileInt("Interpreter", "Ignore Errors", 0);
 	f_setup.expand_abbreviations =
 	    sf_GetProfileInt("Interpreter", "Expand Abbreviations", 0);
-	m_tandy =
+	f_setup.tandy =
 	    sf_GetProfileInt("Interpreter", "Tandy Bit", 0) ? true : false;
 	f_setup.script_cols =
 	    sf_GetProfileInt("Interpreter", "Wrap Script Lines", 1) ? 80 : 0;
@@ -474,11 +472,11 @@ void sf_readsettings(void)
 	}
 
 	sf_FinishProfile();
-}
+} /* sf_readsettings */
 
 
 /* Get a colour */
-ulong sf_GetColour(int colour)
+zlong sf_GetColour(int colour)
 {
 	/* Standard colours */
 	if ((colour >= BLACK_COLOUR) && (colour <= DARKGREY_COLOUR))
@@ -496,20 +494,20 @@ ulong sf_GetColour(int colour)
 			return m_nonStdColours[colour - 18];
 	}
 	return m_colours[0];
-}
+} /* sf_GetColour */
 
 
 /* Get a default colour */
-ulong sf_GetDefaultColour(bool fore)
+zlong sf_GetDefaultColour(bool fore)
 {
 	if (m_IsInfocomV6)
 		return sf_GetColour(fore ? WHITE_COLOUR : BLACK_COLOUR);
 	return fore ? m_defaultFore : m_defaultBack;
-}
+} /* sf_GetColour */
 
 
 /* Get an index for a non-standard colour */
-int sf_GetColourIndex(ulong colour)
+int sf_GetColourIndex(zlong colour)
 {
 	int i, index = -1;
 	/* Is this a standard colour? */
@@ -542,7 +540,7 @@ int sf_GetColourIndex(ulong colour)
 			m_nonStdIndex = 0;
 	}
 	return index;
-}
+} /* sf_GetColourIndex */
 
 
 /*
@@ -587,7 +585,7 @@ void os_set_colour(int new_foreground, int new_background)
 		ts->back = sf_GetColour(new_background);
 	ts->backDefault = (new_background == 1);
 	ts->backTransparent = (new_background == 15);
-}
+} /* os_set_colour */
 
 
 /*
@@ -599,7 +597,7 @@ void os_set_colour(int new_foreground, int new_background)
 int os_from_true_colour(zword colour)
 {
 	return sf_GetColourIndex(RGB5ToTrue(colour));
-}
+} /* os_from_true_colour */
 
 
 /*
@@ -611,7 +609,7 @@ int os_from_true_colour(zword colour)
 zword os_to_true_colour(int index)
 {
 	return TrueToRGB5(sf_GetColour(index));
-}
+} /* os_to_true_colour */
 
 
 /*
@@ -671,7 +669,7 @@ void os_init_screen(void)
 	if (z_header.version == V3) {
 		z_header.config |= CONFIG_SPLITSCREEN;
 		z_header.config |= CONFIG_PROPORTIONAL;
-		if (m_tandy)
+		if (f_setup.tandy)
 			z_header.config |= CONFIG_TANDY;
 		else
 			z_header.config &= ~CONFIG_TANDY;
@@ -745,7 +743,7 @@ void os_init_screen(void)
 		hx_fore_colour = TrueToRGB5(sf_GetDefaultColour(true));
 		hx_back_colour = TrueToRGB5(sf_GetDefaultColour(false));
 	}
-}
+} /* os_init_screen */
 
 
 static void print_c_string (const char *s)
@@ -799,11 +797,11 @@ void os_fatal(const char *s, ...)
 	}
 	sf_cleanup_all();
 	os_quit(EXIT_FAILURE);
-}
+} /* os_fatal */
 
 
 /* If true, running one of Infocom's V6 games */
-bool sf_IsInfocomV6()
+bool sf_IsInfocomV6(void)
 {
 	switch (story_id) {
 	case ARTHUR:
@@ -815,7 +813,7 @@ bool sf_IsInfocomV6()
 		break;
 	}
 	return false;
-}
+} /* sf_IsInfocomV6 */
 
 
 /* If true, this picture has an adaptive palette */
@@ -842,7 +840,7 @@ bool sf_IsAdaptive(int picture)
 	}
 	bb_unload_chunk(blorb_map, result.chunknum);
 	return adaptive;
-}
+} /* sf_IsAdaptive */
 
 
 #define LOCAL_MEM	-1
@@ -870,7 +868,7 @@ void sf_freeresource(myresource * res)
 
 	if ((blorb_map) && (cnu >= 0))
 		bb_unload_chunk(blorb_map, cnu);
-}
+} /* sf_freeresource */
 
 
 static FILE *findlocal(int ispic, int num, int *size)
@@ -888,7 +886,7 @@ static FILE *findlocal(int ispic, int num, int *size)
 	*size = ftell(f);
 	fseek(f, 0, SEEK_SET);
 	return f;
-}
+} /* findlocal */
 
 
 static FILE *findfromlist(int ispic, int num, int *size);
@@ -898,7 +896,7 @@ static int loadlocal(int num, int ispic, int method, myresource * res)
 {
 	FILE *f;
 	int size;
-	byte hd[4];
+	zbyte hd[4];
 
 	f = findlocal(ispic, num, &size);
 	if (!f)
@@ -944,13 +942,13 @@ static int loadlocal(int num, int ispic, int method, myresource * res)
 	}
 
 	return bb_err_None;
-}
+} /* loadlocal */
 
 
 int sf_getresource(int num, int ispic, int method, myresource * res)
 {
 	int st;
-	ulong usage;
+	zlong usage;
 
 	res->bbres.data.ptr = NULL;
 	res->file = NULL;
@@ -974,14 +972,15 @@ int sf_getresource(int num, int ispic, int method, myresource * res)
 			res->file = blorb_fp;
 	}
 	return st;
-}
+} /* sf_getresource */
+
 
 /***************/
 
 typedef struct {
 	void *next;
 	int num, ispic;
-	ulong type;
+	zlong type;
 	char *name;
 } LLENTRY;
 
@@ -989,7 +988,7 @@ static LLENTRY *Lpics = NULL, *Lsnds = NULL;
 
 static int numlocal = 0, numlocalpic = 0, numlocalsnd = 0;
 static int p_ispic, p_num;
-static ulong p_type;
+static zlong p_type;
 static char *p_name;
 
 
@@ -1002,16 +1001,16 @@ static void cleanLLENTRY(LLENTRY * e)
 		free(e);
 		e = n;
 	}
-}
+} /* cleanLLENTRY */
 
 
-static void cleanlocallist()
+static void cleanlocallist(void)
 {
 	cleanLLENTRY(Lpics);
 	Lpics = NULL;
 	cleanLLENTRY(Lsnds);
 	Lsnds = NULL;
-}
+} /* cleanlocal */
 
 
 static int parseline(char *s)
@@ -1047,7 +1046,7 @@ static int parseline(char *s)
 		return -1;
 	p_name = p;
 	return 1;
-}
+} /* parseline */
 
 
 static void load_local_resources(void)
@@ -1090,7 +1089,7 @@ static void load_local_resources(void)
 	if (numlocal)
 		m_localfiles = 1;
 	fclose(f);
-}
+} /* load_local_resources */
 
 
 static FILE *findfromlist(int ispic, int num, int *size)
@@ -1121,7 +1120,7 @@ static FILE *findfromlist(int ispic, int num, int *size)
 	*size = ftell(f);
 	fseek(f, 0, SEEK_SET);
 	return f;
-}
+} /* findfromlist */
 
 
 void os_init_setup(void)
@@ -1130,4 +1129,4 @@ void os_init_setup(void)
 	sf_setdialog();
 	sf_initloader();
 	sdl_active = FALSE;
-}
+} /* os_init_setup */
