@@ -21,6 +21,11 @@
 
 #include "sf_frotz.h"
 
+int m_no_sound = 0;
+int m_frequency = 44100;
+
+#ifndef NO_SOUND
+
 #include <stdarg.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -52,17 +57,15 @@ typedef struct EFFECT {
 	int volume;
 	int ended;
 	zword eos;
-	ulong endtime;
+	zlong endtime;
 } EFFECT;
 
 /* no effects cache */
 static EFFECT *e_sfx = NULL;
 static EFFECT *e_mod = NULL;
 
-int SFaudiorunning = 0;
+static int SFaudiorunning = 0;
 volatile int end_of_sound_flag = 0;
-int m_no_sound = 0;
-int m_frequency = 44100;
 
 static int audio_rate, audio_channels;
 
@@ -73,7 +76,7 @@ static int audio_buffers = 512;
 static Uint16 audio_format;
 static int bits;
 
-static void finishaudio()
+static void finishaudio(void)
 {
 	if (!SFaudiorunning)
 		return;
@@ -89,7 +92,8 @@ static void finishaudio()
 	e_sfx = e_mod = NULL;
 
 	Mix_CloseAudio();
-}
+} /* finishaudio */
+
 
 static void music_finished(void);
 static void channel_finished(int channel);
@@ -99,11 +103,12 @@ static void channel_finished(int channel);
  * whether sound is desired and has no means for indicating whether sound is
  * available.  See sf_initsound for the real init.
  */
-void os_init_sound()
+void os_init_sound(void)
 {
-}
+} /* os_init_sound */
 
-int sf_initsound()
+
+int sf_initsound(void)
 {
 	if (SFaudiorunning)
 		return 1;
@@ -129,7 +134,7 @@ int sf_initsound()
 	Mix_AllocateChannels(1);
 	CLEANREG(finishaudio);
 	return 1;
-}
+} /* sf_initsound */
 
 
 static void baredestroy(EFFECT * r)
@@ -141,7 +146,7 @@ static void baredestroy(EFFECT * r)
 			Mix_FreeChunk(r->sam);
 		free(r);
 	}
-}
+} /* baredestroy */
 
 
 static EFFECT *new_effect(int type, int num)
@@ -153,7 +158,7 @@ static EFFECT *new_effect(int type, int num)
 		reader->destroy = baredestroy;
 	}
 	return (EFFECT *) reader;
-}
+} /* new_effect */
 
 
 /* According to specs, this is only called when music ends "naturally",
@@ -167,7 +172,7 @@ static void music_finished(void)
 		return;
 	e_mod->active = 0;
 	e_mod->ended = 1;
-}
+} /* music_finished */
 
 
 /* This may be called also via a Mix_Haltetc. */
@@ -181,10 +186,10 @@ static void channel_finished(int channel)
 		return;
 	e_sfx->active = 0;
 	e_sfx->ended = 1;	/* stopsample will take care of this... */
-}
+} /* channel_finished */
 
 
-static void stopsample()
+static void stopsample(void)
 {
 	if (!e_sfx)
 		return;
@@ -193,40 +198,40 @@ static void stopsample()
 	e_sfx->active = 0;
 	Mix_HaltChannel(0);
 	e_sfx->ended = 0;
-}
+} /* stopsample */
 
 
-static void stopmodule()
+static void stopmodule(void)
 {
 	if (!e_mod)
 		return;
 	e_mod->active = 0;
 	Mix_HaltMusic();
 	e_mod->ended = 0;
-}
+} /* stopmodule */
 
 
-static void startsample()
+static void startsample(void)
 {
 	if (!e_sfx)
 		return;
 	Mix_PlayChannel(0, e_sfx->sam, e_sfx->repeats);
 	Mix_Volume(0, e_sfx->volume);
 	e_sfx->active = 1;
-}
+} /* startsample */
 
 
-static void startmodule()
+static void startmodule(void)
 {
 	if (!e_mod)
 		return;
 	Mix_PlayMusic(e_mod->mod, e_mod->repeats);
 	Mix_VolumeMusic(e_mod->volume);
 	e_mod->active = 1;
-}
+} /* startmodule */
 
 
-static EFFECT *getaiff(FILE * f, size_t pos, int len, int num)
+static EFFECT *getaiff(FILE * f, size_t pos, int UNUSED (len), int num)
 {
 	EFFECT *res = NULL;
 
@@ -240,13 +245,13 @@ static EFFECT *getaiff(FILE * f, size_t pos, int len, int num)
 		return NULL;
 	}
 	return res;
-}
+} /* getaiff */
 
 
-static EFFECT *getmodule(FILE * f, size_t pos, int len, int num)
+static EFFECT *getmodule(FILE * f, size_t pos, int UNUSED (len), int num)
 {
 	EFFECT *res;
-	byte h[2];
+	zbyte h[2];
 
 	res = new_effect(MOD_TYPE, num);
 	if (!res)
@@ -274,7 +279,7 @@ static EFFECT *getmodule(FILE * f, size_t pos, int len, int num)
 		return NULL;
 	}
 	return res;
-}
+} /* getmodule */
 
 
 static EFFECT *geteffect(int num)
@@ -306,7 +311,8 @@ static EFFECT *geteffect(int num)
 	sf_freeresource(&res);
 
 	return result;
-}
+} /* geteffect */
+
 
 /* sound handling */
 
@@ -317,7 +323,7 @@ static EFFECT *geteffect(int num)
  * or low-pitched (number == 2).
  *
  */
-void os_beep(int number)
+void os_beep(int UNUSED (number))
 {
 	if (m_no_sound)
 		return;
@@ -327,7 +333,7 @@ void os_beep(int number)
 		return;
 /*	theWnd->FlushDisplay();
 	::MessageBeep(MB_ICONEXCLAMATION);*/
-}
+} /* os_beep */
 
 
 /*
@@ -341,7 +347,7 @@ void os_finish_with_sample(int number)
 	if (!SFaudiorunning)
 		return;
 	os_stop_sample(number);
-}
+} /* os_finish_with_sample */
 
 
 /*
@@ -350,11 +356,11 @@ void os_finish_with_sample(int number)
  * Load the given sample from the disk.
  *
  */
-void os_prepare_sample(int number)
+void os_prepare_sample(int UNUSED (number))
 {
 	if (!SFaudiorunning)
 		return;
-}
+} /* os_prepare_sample */
 
 
 /*
@@ -408,7 +414,7 @@ void os_start_sample(int number, int volume, int repeats, zword eos)
 		e_mod = e;
 		startmodule();
 	}
-}
+} /* os_start_sample */
 
 
 /*
@@ -430,10 +436,10 @@ void os_stop_sample(int number)
 		stopsample();
 	if ((e_mod) && (e_mod->number == number))
 		stopmodule();
-}
+} /* os_stop_sample */
 
 
-void sf_checksound()
+void sf_checksound(void)
 {
 	if ((e_sfx) && (e_sfx->ended)) {
 		e_sfx->ended = 0;
@@ -449,6 +455,55 @@ void sf_checksound()
 			end_of_sound();
 		}
 	}
+} /* sf_checksound */
+
+/*************************************/
+
+#else /* NO_SOUND */
+
+/* Dummy functions */
+
+void os_init_sound(void)
+{
+	/* Not implemented */
 }
+
+int sf_initsound(void)
+{
+	/* Not implemented */
+	return 0;
+}
+
+void os_beep(int UNUSED (number))
+{
+	/* Not implemented */
+}
+
+void os_finish_with_sample(int number)
+{
+	/* Not implemented */
+}
+
+void os_prepare_sample(int UNUSED (number))
+{
+	/* Not implemented */
+}
+
+void os_start_sample(int number, int volume, int repeats, zword eos)
+{
+	/* Not implemented */
+}
+
+void os_stop_sample(int number)
+{
+	/* Not implemented */
+}
+
+void sf_checksound(void)
+{
+	/* Not implemented */
+}
+
+#endif /* NO_SOUND */
 
 /*************************************/
