@@ -21,6 +21,7 @@
 
 #include "sf_frotz.h"
 
+#include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -72,10 +73,10 @@ void sf_regcleanfunc(void *f, const char *p)
 		n->next = cflist;
 		cflist = n;
 	}
-}
+} /* sf_regcleanfunc */
 
 
-void sf_cleanup_all()
+void sf_cleanup_all(void)
 {
 	while (cflist) {
 		cfrec *n = cflist->next;
@@ -84,7 +85,7 @@ void sf_cleanup_all()
 		free(cflist);
 		cflist = n;
 	}
-}
+} /* sf_cleanup_all */
 
 
 /*
@@ -97,19 +98,19 @@ void os_reset_screen(void)
 {
 	sf_flushdisplay();
 
-	if (m_exitPause) {
-		const char *hit = sf_msgstring(IDS_HIT_KEY_EXIT);
-		os_set_font(TEXT_FONT);
-		os_set_text_style(0);
-		screen_new_line();
+	const char *hit = sf_msgstring(IDS_HIT_KEY_EXIT);
+	os_set_font(TEXT_FONT);
+	os_set_text_style(0);
+	screen_new_line();
 
-		while (*hit)
-			os_display_char((*hit++));
-		sf_read_key(0, true, false, false);
-	}
+	while (*hit)
+		os_display_char((*hit++));
+	sf_read_key(0, true, false, false);
 
 	sf_cleanup_all();
-}
+} /* os_reset_screen */
+
+
 /*
  * os_quit
  *
@@ -121,6 +122,7 @@ void os_quit(int status)
 	exit(status);
 } /* os_quit */
 
+
 int user_background = -1;
 int user_foreground = -1;
 int user_emphasis = -1;
@@ -129,7 +131,6 @@ int user_reverse_bg = -1;
 int user_reverse_fg = -1;
 int user_screen_height = -1;
 int user_screen_width = -1;
-int user_tandy_bit = -1;
 int user_font = 1;
 int m_random_seed = -1;
 int m_fullscreen = -1;
@@ -237,7 +238,7 @@ static void usage(int type)
 		puts(info_footer);
 	puts(footer);
 
-}
+} /* usage */
 
 
 /*
@@ -274,7 +275,7 @@ static int limit(int v, int m, int M)
 	if (v > M)
 		return M;
 	return v;
-}
+} /* limit */
 
 
 static void parse_options(int argc, char **argv)
@@ -356,7 +357,7 @@ static void parse_options(int argc, char **argv)
 		if (c == 'S')
 			f_setup.script_cols = num;
 		if (c == 't')
-			user_tandy_bit = 1;
+			f_setup.tandy = 1;
 		if (c == 'T')
 			sf_osdialog = NULL;
 		if (c == 'u')
@@ -391,7 +392,7 @@ static void print_version(void)
 	printf("Git commit:     %s\n", GIT_HASH);
 	printf("Notes:          %s\n", RELEASE_NOTES);
 	printf("  Frotz was originally written by Stefan Jokisch.\n");
-	printf("  It complies with standard 1.0 of Graham Nelson's specification.\n");
+	printf("  It complies with standard 1.1 of the Z-Machine Standard.\n");
 	printf("  It was ported to Unix by Galen Hazelwood.\n");
 	printf("  It is distributed under the GNU General Public License version 2 or\n");
 	printf("    (at your option) any later version.\n");
@@ -399,7 +400,7 @@ static void print_version(void)
 	printf("  The core and SDL port are maintained by David Griffith.\n");
 	printf("  Frotz's homepage is https://661.org/proj/if/frotz/\n\n");
 	os_quit(EXIT_SUCCESS);
-}
+} /* print_version */
 
 
 /**
@@ -411,7 +412,7 @@ static char *new_dirname(const char *path)
 	char *p = strdup(path), *p2 = strdup(dirname(p));
 	free(p);
 	return p2;
-}
+} /* new_dirname */
 
 
 /**
@@ -423,7 +424,7 @@ static char *new_basename(const char *path)
 	char *p = strdup(path), *p2 = strdup(basename(p));
 	free(p);
 	return p2;
-}
+} /* new_basename */
 
 
 /*
@@ -520,8 +521,6 @@ void os_process_arguments(int argc, char *argv[])
 		m_defaultBack = sf_GetColour(user_background);
 	if (user_foreground != -1)
 		m_defaultFore = sf_GetColour(user_foreground);
-	if (user_tandy_bit != -1)
-		m_tandy = user_tandy_bit;
 
 	sf_initfonts();
 } /* os_process_arguments */
@@ -537,20 +536,21 @@ void os_process_arguments(int argc, char *argv[])
 void sf_sleep(int msecs)
 {
 	SDL_Delay(msecs);
-}
+} /* sf_sleep */
+
 
 #ifdef WIN32
-unsigned long sf_ticks(void)
+zlong sf_ticks(void)
 {
 	return (GetTickCount());
 }
 #else
-unsigned long sf_ticks(void)
+zlong sf_ticks(void)
 {
 	struct timeval now;
 	static struct timeval start;
 	static int started = 0;
-	unsigned long ticks;
+	zlong ticks;
 	now.tv_sec = now.tv_usec = 0;
 	gettimeofday(&now, NULL);
 	if (!started) {
@@ -561,7 +561,7 @@ unsigned long sf_ticks(void)
 	    (now.tv_sec - start.tv_sec) * 1000 + (now.tv_usec -
 						  start.tv_usec) / 1000;
 	return ticks;
-}
+} /* sf_ticks */
 #endif
 
 
@@ -577,7 +577,7 @@ static char *getextension(int flag)
 		ext = EXT_COMMAND;
 
 	return ext;
-}
+} /* getextension */
 
 
 static bool newfile(int flag)
@@ -585,12 +585,12 @@ static bool newfile(int flag)
 	if (flag == FILE_SAVE || flag == FILE_SAVE_AUX || flag == FILE_RECORD)
 		return true;
 	return false;
-}
+} /* newfile */
 
 
 static char buf[FILENAME_MAX];
 
-static const char *getnumbername(const char *def, char *ext)
+static const char *getnumbername(const char * UNUSED(def), char *ext)
 {
 	int len, number = 0;
 	strcpy(buf, f_setup.story_name);
@@ -601,10 +601,10 @@ static const char *getnumbername(const char *def, char *ext)
 			break;
 	}
 	return buf;
-}
+} /* getnumbername */
 
 
-static const char *getdatename(const char *def, char *ext)
+static const char *getdatename(const char * UNUSED (def), char *ext)
 {
 	int len;
 
@@ -619,7 +619,7 @@ static const char *getdatename(const char *def, char *ext)
 		tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
 		tm->tm_hour, tm->tm_min, ext);
 	return buf;
-}
+} /* getdatename */
 
 
 static int ingame_read_file_name(char *file_name, const char *default_name,
@@ -632,13 +632,14 @@ static int dialog_read_file_name(char *file_name, const char *default_name,
  *
  * Return the name of a file. Flag can be one of:
  *
- *    FILE_SAVE     - Save game file
- *    FILE_RESTORE  - Restore game file
- *    FILE_SCRIPT   - Transscript file
- *    FILE_RECORD   - Command file for recording
- *    FILE_PLAYBACK - Command file for playback
- *    FILE_SAVE_AUX - Save auxilary ("preferred settings") file
- *    FILE_LOAD_AUX - Load auxilary ("preferred settings") file
+ *    FILE_SAVE      - Save game file
+ *    FILE_RESTORE   - Restore game file
+ *    FILE_SCRIPT    - Transcript file
+ *    FILE_RECORD    - Command file for recording
+ *    FILE_PLAYBACK  - Command file for playback
+ *    FILE_SAVE_AUX  - Save auxilary ("preferred settings") file
+ *    FILE_LOAD_AUX  - Load auxilary ("preferred settings") file
+ *    FILE_NO_PROMPT - Return file without prompting the user
  *
  * The length of the file name is limited by MAX_FILE_NAME. Ideally
  * an interpreter should open a file requester to ask for the file
@@ -652,20 +653,28 @@ char *os_read_file_name(const char *default_name, int flag)
 	int st;
 	const char *initname = default_name;
 	char file_name[FILENAME_MAX + 1];
+	char *ext;
 
 	if (newfile(flag)) {
-		char *ext = getextension(flag);
+		char *flag_ext = getextension(flag);
 		if (m_names_format == 'd')
-			initname = getdatename(initname, ext);
+			initname = getdatename(initname, flag_ext);
 		else if (m_names_format == 'n')
-			initname = getnumbername(initname, ext);
+			initname = getnumbername(initname, flag_ext);
 	}
 
 	/* If we're restoring a game before the interpreter starts,
 	 * and our filename is already provided with the -L flag,
 	 * just go ahead silently.
 	 */
-	if (f_setup.restore_mode) {
+	if (flag == FILE_NO_PROMPT) {
+		const char *ext = strrchr(default_name, '.');
+		if (strncmp(ext, EXT_AUX, 4)) {
+			os_warn("Blocked unprompted access of %s. Should only be %s files.", default_name, EXT_AUX);
+			return NULL;
+		} else
+			strncpy(file_name, default_name, FILENAME_MAX);
+	} else if (f_setup.restore_mode) {
 		strncpy(file_name, f_setup.save_name, FILENAME_MAX);
 	} else {
 		st = dialog_read_file_name(file_name, initname, flag);
@@ -674,10 +683,29 @@ char *os_read_file_name(const char *default_name, int flag)
 
 		if (!st)
 			return NULL;
-	}
 
+		/* Add appropriate filename extensions if not already there. */
+		ext = strrchr(file_name, '.');
+		if (flag == FILE_SAVE || flag == FILE_RESTORE) {
+			if (ext == NULL ||  (strncmp(ext, EXT_SAVE, EXT_LENGTH) != 0) ) {
+				strncat(file_name, EXT_SAVE, EXT_LENGTH);
+			}
+		} else if (flag == FILE_SCRIPT) {
+			if (ext == NULL || strncmp(ext, EXT_SCRIPT, EXT_LENGTH) != 0) {
+				strncat(file_name, EXT_SCRIPT, EXT_LENGTH);
+			}
+		} else if (flag == FILE_SAVE_AUX || flag == FILE_LOAD_AUX) {
+			if (ext == NULL || strncmp(ext, EXT_AUX, EXT_LENGTH) != 0) {
+				strncat(file_name, EXT_AUX, EXT_LENGTH);
+			}
+		} else if (flag == FILE_RECORD || flag == FILE_PLAYBACK) {
+			if (ext == NULL || strncmp(ext, EXT_COMMAND, EXT_LENGTH) != 0) {
+				strncat(file_name, EXT_COMMAND, EXT_LENGTH);
+			}
+		}
+	}
 	return strdup(file_name);
-}
+} /* os_read_file_name */
 
 
 static int ingame_read_file_name(char *file_name, const char *default_name,
@@ -710,21 +738,21 @@ static int ingame_read_file_name(char *file_name, const char *default_name,
 		zchar z_name[FILENAME_MAX + 1];
 		zchar *zp;
 		int i = 0;
-		read_string(FILENAME_MAX - 4, z_name);
+		read_string(FILENAME_MAX - EXT_LENGTH - 4, z_name);
 		zp = z_name;
 		while (*zp) {
 			if (*zp <= 0x7f) {
-				if (i > FILENAME_MAX - 4)
+				if (i > FILENAME_MAX - EXT_LENGTH - 4)
 					break;
 				file_name[i++] = *zp;
 			} else if (*zp > 0x7ff) {
-				if (i > FILENAME_MAX - 6)
+				if (i > FILENAME_MAX - EXT_LENGTH - 6)
 					break;
 				file_name[i++] = 0xe0 | ((*zp >> 12) & 0xf);
 				file_name[i++] = 0x80 | ((*zp >> 6) & 0x3f);
 				file_name[i++] = 0x80 | (*zp & 0x3f);
 			} else {
-				if (i > FILENAME_MAX - 5)
+				if (i > FILENAME_MAX - EXT_LENGTH - 5)
 					break;
 				file_name[i++] = 0xc0 | ((*zp >> 6) & 0x1f);
 				file_name[i++] = 0x80 | (*zp & 0x3f);
@@ -734,7 +762,7 @@ static int ingame_read_file_name(char *file_name, const char *default_name,
 		file_name[i] = 0;
 	}
 #else
-	read_string(MAX_FILE_NAME - 4, (zchar *) file_name);
+	read_string(MAX_FILE_NAME - EXT_LENGTH - 4, (zchar *) file_name);
 #endif
 
 	/* Use the default name if nothing was typed */
@@ -772,7 +800,7 @@ static int ingame_read_file_name(char *file_name, const char *default_name,
 	ostream_record = saved_record;
 
 	return result;
-} /* os_read_file_name */
+} /* ingame_read_file_name */
 
 
 static int dialog_read_file_name(char *file_name, const char *default_name,
@@ -822,22 +850,22 @@ static int dialog_read_file_name(char *file_name, const char *default_name,
 	if (st == SF_NOTIMP)
 		return st;
 	if (st == 0) {
-		strncpy(file_name, res, MAX_FILE_NAME);
+		strncpy(file_name, res, MAX_FILE_NAME - EXT_LENGTH);
 		file_name[MAX_FILE_NAME - 1] = 0;
 		return 1;
 	}
 	return 0;
-}
+} /* dialog_read_file_name */
 
 static char *rc = NULL;
 
-void sf_FinishProfile()
+void sf_FinishProfile(void)
 {
 	if (!rc)
 		return;
 	free(rc);
 	rc = NULL;
-}
+} /* sf_FinishProfile */
 
 
 void sf_InitProfile(const char *fn)
@@ -893,7 +921,7 @@ void sf_InitProfile(const char *fn)
 	*d = 0;
 
 	CLEANREG(sf_FinishProfile);
-}
+} /* sf_InitProfile */
 
 
 static char *findsect(const char *sect)
@@ -910,7 +938,7 @@ static char *findsect(const char *sect)
 		return (r + ns);
 	}
 	return NULL;
-}
+} /* findsect */
 
 
 static char *findid(const char *sect, const char *id)
@@ -928,7 +956,7 @@ static char *findid(const char *sect, const char *id)
 		if (!r)
 			break;
 		rq = r + nid;
-		if ((*(byte *) (r - 1) <= ' ')
+		if ((*(zbyte *) (r - 1) <= ' ')
 		    && ((*rq == ' ') || (*rq == '='))) {
 			while (*rq)
 				if (*rq++ == '=')
@@ -943,7 +971,7 @@ static char *findid(const char *sect, const char *id)
 	if (sav)
 		*sav = '[';
 	return fnd;
-}
+} /* findid */
 
 
 int sf_GetProfileInt(const char *sect, const char *id, int def)
@@ -954,7 +982,7 @@ int sf_GetProfileInt(const char *sect, const char *id, int def)
 			def = atoi(p);
 	}
 	return def;
-}
+} /* sf_GetProfileInt */
 
 
 double sf_GetProfileDouble(const char *sect, const char *id, double def)
@@ -965,7 +993,7 @@ double sf_GetProfileDouble(const char *sect, const char *id, double def)
 			def = atof(p);
 	}
 	return def;
-}
+} /* sf_GetProfileDouble */
 
 
 char *sf_GetProfileString(const char *sect, const char *id, char *def)
@@ -981,7 +1009,7 @@ char *sf_GetProfileString(const char *sect, const char *id, char *def)
 					p++;
 					break;
 				}
-				if ((byte) (*p) > ' ')
+				if ((zbyte) (*p) > ' ')
 					break;
 			}
 			if (*p) {
@@ -1005,7 +1033,7 @@ char *sf_GetProfileString(const char *sect, const char *id, char *def)
 	if (sav)
 		*q = sav;
 	return def;
-}
+} /* sf_GetProfileString */
 
 
 /*  A.  Local file header:
@@ -1032,23 +1060,23 @@ char *sf_GetProfileString(const char *sect, const char *id, char *def)
 #define pshort( b) (((int)((b)[1]) << 8) + (int)((b)[0]))
 
 
-static unsigned myin(void *d, byte ** b)
+static unsigned myin(void * UNUSED (d), zbyte ** UNUSED (b))
 {
 	return 0;
-}
+} /* myin */
 
 
-static int myout(void *udata, byte * b, unsigned n)
+static int myout(void *udata, zbyte * b, unsigned n)
 {
 	memmove(udata, b, n);
 	udata += n;
 	return 0;
-}
+} /* myout */
 
 
-static int myunzip(int csize, byte * cdata, byte * udata)
+static int myunzip(int csize, zbyte * cdata, zbyte * udata)
 {
-	byte window[32768];
+	zbyte window[32768];
 	z_stream z;
 	int st;
 
@@ -1071,13 +1099,13 @@ static int myunzip(int csize, byte * cdata, byte * udata)
 
 	st = inflateBackEnd(&z);
 	return st;
-}
+} /* myunzip */
 
 
 int sf_pkread(FILE * f, int foffs, void **out, int *size)
 {
-	byte hd[30];
-	byte *data, *cdata;
+	zbyte hd[30];
+	zbyte *data, *cdata;
 	int csize, usize, cmet, skip, st;
 
 	fseek(f, foffs, SEEK_SET);
@@ -1113,7 +1141,7 @@ int sf_pkread(FILE * f, int foffs, void **out, int *size)
 	*out = (void *)data;
 	*size = usize;
 	return st;
-}
+} /* sf_pkread */
 
 
 /*
