@@ -21,6 +21,7 @@
 
 #include "sf_frotz.h"
 
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -31,7 +32,7 @@
 
 static char banner[256];
 static int isfullscreen;
-static ulong *sbuffer = NULL;
+static zlong *sbuffer = NULL;
 static int sbpitch;		/* in longs */
 static int dirty = 0;
 static int ewidth, eheight;
@@ -42,10 +43,10 @@ int m_timerinterval = 100;
 
 extern bool sdl_active;
 
-static void sf_quitconf();
+static void sf_quitconf(void);
 
 static bool ApplyPalette(sf_picture *);
-static ulong screen_palette[16];
+static zlong screen_palette[16];
 
 extern z_header_t z_header;
 
@@ -70,7 +71,7 @@ void sf_setclip(int x, int y, int w, int h)
 	xmax = x + w;
 	ymin = y;
 	ymax = y + h;
-}
+} /* sf_setclip */
 
 
 void sf_getclip(int *x, int *y, int *w, int *h)
@@ -79,7 +80,7 @@ void sf_getclip(int *x, int *y, int *w, int *h)
 	*y = ymin;
 	*w = xmax - xmin;
 	*h = ymax - ymin;
-}
+} /* sf_getclip */
 
 
 static int mywcslen(zchar * b)
@@ -88,35 +89,35 @@ static int mywcslen(zchar * b)
 	while (*b++)
 		n++;
 	return n;
-}
+} /* mywcslen */
 
 
-static void myGrefresh()
+static void myGrefresh(void)
 {
 	SDL_RenderClear(renderer);
 	SDL_RenderCopy(renderer, texture, NULL, NULL);
 	SDL_RenderPresent(renderer);
-}
+} /* myGrefresh */
 
 
-void sf_wpixel(int x, int y, ulong c)
+void sf_wpixel(int x, int y, zlong c)
 {
 	if (x < xmin || x >= xmax || y < ymin || y >= ymax)
 		return;
 	sbuffer[x + sbpitch * y] = c;
 	dirty = 1;
-}
+} /* sf_wpixel */
 
 
-ulong sf_rpixel(int x, int y)
+zlong sf_rpixel(int x, int y)
 {
 	if (x < 0 || x >= ewidth || y < 0 || y >= eheight)
 		return 0;
 	return sbuffer[x + sbpitch * y];
-}
+} /* sf_rpixel */
 
 #define MAXCUR 64
-static ulong savedcur[MAXCUR];
+static zlong savedcur[MAXCUR];
 
 static void drawthecursor(int x, int y, int onoff)
 {
@@ -134,10 +135,10 @@ static void drawthecursor(int x, int y, int onoff)
 			sf_wpixel(x, y + i, savedcur[i]);
 		}
 	}
-}
+} /* drawthecursor */
 
 
-bool sf_IsValidChar(unsigned short c)
+bool sf_IsValidChar(zword c)
 {
 	if (c >= ZC_ASCII_MIN && c <= ZC_ASCII_MAX)
 		return true;
@@ -146,19 +147,19 @@ bool sf_IsValidChar(unsigned short c)
 	if (c >= 0x100)
 		return true;
 	return false;
-}
+} /* sf_IsValidChar */
 
 
 void sf_drawcursor(bool c)
 {
 	SF_textsetting *ts = sf_curtextsetting();
 	drawthecursor(ts->cx, ts->cy, c);
-}
+} /* sf_drawcursor */
 
 
-void sf_chline(int x, int y, ulong c, int n)
+void sf_chline(int x, int y, zlong c, int n)
 {
-	ulong *s;
+	zlong *s;
 	if (y < ymin || y >= ymax)
 		return;
 	if (x < xmin) {
@@ -173,12 +174,12 @@ void sf_chline(int x, int y, ulong c, int n)
 	while (n--)
 		*s++ = c;
 	dirty = 1;
-}
+} /* sf_chline */
 
 
-void sf_cvline(int x, int y, ulong c, int n)
+void sf_cvline(int x, int y, zlong c, int n)
 {
-	ulong *s;
+	zlong *s;
 	if (x < xmin || x >= xmax)
 		return;
 	if (y < xmin) {
@@ -195,12 +196,12 @@ void sf_cvline(int x, int y, ulong c, int n)
 		s += sbpitch;
 	}
 	dirty = 1;
-}
+} /* sf_cvline */
 
 
-ulong sf_blendlinear(int a, ulong s, ulong d)
+zlong sf_blendlinear(int a, zlong s, zlong d)
 {
-	ulong r;
+	zlong r;
 	r = ((s & 0xff) * a + (d & 0xff) * (256 - a)) >> 8;
 	s >>= 8;
 	d >>= 8;
@@ -209,7 +210,7 @@ ulong sf_blendlinear(int a, ulong s, ulong d)
 	d >>= 8;
 	r |= (((s & 0xff) * a + (d & 0xff) * (256 - a)) >> 8) << 16;
 	return r;
-}
+} /* sf_blendlinear */
 
 
 void sf_writeglyph(SF_glyph * g)
@@ -220,7 +221,7 @@ void sf_writeglyph(SF_glyph * g)
 
 	int w = g->dx;
 	int weff = g->xof + g->w;
-	byte *bmp = (byte *) (&(g->bitmap[0]));
+	zbyte *bmp = (zbyte *) (&(g->bitmap[0]));
 	int h = g->h;
 	int nby = (g->w + 7) / 8;
 	int byw = g->w;
@@ -234,7 +235,7 @@ void sf_writeglyph(SF_glyph * g)
 	int height = ts->font->height(ts->font);
 	int width;
 
-	ulong color, bc;
+	zlong color, bc;
 
 	if ((ts->style & REVERSE_STYLE) != 0) {
 		bc = ts->fore;
@@ -262,7 +263,7 @@ void sf_writeglyph(SF_glyph * g)
 				int t = *bmp++;
 				if (xx < byw) {
 					if (t) {
-						ulong sval = color;
+						zlong sval = color;
 						if (t < 255)
 							sval = sf_blend((int) (t + (t >> 7)), sval, sf_rpixel(x + xx, y));
 						sf_wpixel(x + xx, y, sval);
@@ -287,12 +288,12 @@ void sf_writeglyph(SF_glyph * g)
 
 	ts->cx += (w);
 	ts->oh = (weff > w) ? weff - w : 0;
-}
+} /* sf_writeglyph */
 
 
-void sf_fillrect(unsigned long color, int x, int y, int w, int h)
+void sf_fillrect(zlong color, int x, int y, int w, int h)
 {
-	ulong *dst;
+	zlong *dst;
 	int i;
 	if (x < xmin) {
 		w += x - xmin;
@@ -317,24 +318,24 @@ void sf_fillrect(unsigned long color, int x, int y, int w, int h)
 		dst += sbpitch;
 	}
 	dirty = 1;
-}
+} /* sf_fillrect */
 
 
-void sf_rect(unsigned long color, int x, int y, int w, int h)
+void sf_rect(zlong color, int x, int y, int w, int h)
 {
 	sf_chline(x, y, color, w);
 	sf_chline(x, y + h - 1, color, w);
 	sf_cvline(x, y, color, h);
 	sf_cvline(x + w - 1, y, color, h);
-}
+} /* sf_rect */
 
 
-void sf_flushtext()
+void sf_flushtext(void)
 {
 	SF_textsetting *ts = sf_curtextsetting();
 	ts->cx += ts->oh;
 	ts->oh = 0;
-}
+} /* sf_flushtext */
 
 
 /*
@@ -348,12 +349,12 @@ void sf_flushtext()
  * being erased.
  *
  */
-void os_erase_area(int top, int left, int bottom, int right, int win)
+void os_erase_area(int top, int left, int bottom, int right, int UNUSED (win))
 {
 	sf_flushtext();
 	sf_fillrect((sf_curtextsetting())->back, left - 1, top - 1,
 		    right - left + 1, bottom - top + 1);
-}
+} /* os_erase_area */
 
 
 /*
@@ -375,12 +376,12 @@ int os_peek_colour(void)
 	SF_textsetting *ts = sf_curtextsetting();
 	sf_flushtext();
 	return sf_GetColourIndex(sf_rpixel(ts->cx, ts->cy));
-}
+} /* os_peek_colour */
 
 
 static void scroll(int x, int y, int w, int h, int n)
 {
-	ulong *src, *dst;
+	zlong *src, *dst;
 	int nmove, step;
 	if (n > 0) {
 		dst = sbuffer + x + sbpitch * y;
@@ -397,30 +398,30 @@ static void scroll(int x, int y, int w, int h, int n)
 		return;
 	if (nmove > 0) {
 		while (nmove--) {
-			memmove(dst, src, w * sizeof(ulong));
+			memmove(dst, src, w * sizeof(zlong));
 			dst += step;
 			src += step;
 		}
 		dirty = 1;
 	}
-}
+} /* scroll */
 
 
 /**
  * Update the display if contents have changed.
  * Return whether contents had changed, i.e., display was updated.
  */
-bool sf_flushdisplay()
+bool sf_flushdisplay(void)
 {
 	if (dirty) {
 		SDL_UpdateTexture(texture, NULL, sbuffer,
-				  sbpitch * sizeof(ulong));
+				  sbpitch * sizeof(zlong));
 		myGrefresh();
 		dirty = 0;
 		return true;
 	} else
 		return false;
-}
+} /* sf_flushdisplay */
 
 
 /*
@@ -442,15 +443,16 @@ void os_scroll_area(int top, int left, int bottom, int right, int units)
 	else if (units < 0)
 		sf_fillrect((sf_curtextsetting())->back, left - 1, top - 1,
 			    right - left + 1, units);
-}
+} /* os_scroll_area */
 
 
-bool os_repaint_window(int win, int ypos_old, int ypos_new, int xpos,
-		       int ysize, int xsize)
+bool os_repaint_window(int UNUSED (win), int UNUSED (ypos_old),
+		int UNUSED (ypos_new), int UNUSED (xpos),
+		int UNUSED (ysize), int UNUSED (xsize))
 {
 	/* TODO */
 	return FALSE;
-}
+} /* os_repaint_window */
 
 
 int SFdticks = 200;
@@ -458,7 +460,7 @@ static SDL_atomic_t SFticked = {0};
 static SDL_TimerID timerid = 0;
 static Uint32 refreshEventType = 0;
 
-static Uint32 SDLCALL mytimer(Uint32 inter, void *parm)
+static Uint32 SDLCALL mytimer(Uint32 inter, void * UNUSED (parm))
 {
 	SDL_AtomicSet(&SFticked, 1);
 	SDL_Event event = {0};
@@ -466,21 +468,21 @@ static Uint32 SDLCALL mytimer(Uint32 inter, void *parm)
 	event.user.type = refreshEventType;
 	SDL_PushEvent(&event);
 	return inter;
-}
+} /* mytimer */
 
 
-static void cleanvideo()
+static void cleanvideo(void)
 {
 	if (timerid)
 		SDL_RemoveTimer(timerid);
 	SDL_Quit();
-}
+} /* cleanvideo */
 
 #define RM 0x0000ff
 #define GM 0x00ff00
 #define BM 0xff0000
 
-static void sf_toggle_fullscreen()
+static void sf_toggle_fullscreen(void)
 {
 	if (SDL_SetWindowFullscreen
 	    (window, isfullscreen ? 0 : SDL_WINDOW_FULLSCREEN_DESKTOP))
@@ -492,7 +494,7 @@ static void sf_toggle_fullscreen()
 			SDL_SetWindowSize(window, AcWidth, AcHeight);
 		myGrefresh();
 	}
-}
+} /* sf_toggle_fullscreen */
 
 
 void sf_initvideo(int W, int H, int full)
@@ -537,7 +539,7 @@ void sf_initvideo(int W, int H, int full)
 					  SDL_TEXTUREACCESS_STREAMING, W, H)))
 		os_fatal("Failed to create texture: %s", SDL_GetError());
 
-	sbuffer = calloc(W * H, sizeof(ulong));
+	sbuffer = calloc(W * H, sizeof(zlong));
 	if (!sbuffer)
 		os_fatal("Could not create gc");
 
@@ -549,7 +551,7 @@ void sf_initvideo(int W, int H, int full)
 	ymax = eheight = H;
 	sbpitch = W;
 	dirty = 1;
-}
+} /* sf_initvideo */
 
 
 /*
@@ -564,7 +566,7 @@ void os_draw_picture(int picture, int y, int x)
 	int ox, oy, ow, oh;
 	Zwindow *winpars;
 	sf_picture *pic = sf_getpic(picture);
-	ulong *src, *dst, sval, dval, alpha;
+	zlong *src, *dst, sval, dval, alpha;
 
 	sf_flushtext();
 
@@ -572,7 +574,7 @@ void os_draw_picture(int picture, int y, int x)
 		return;
 	if (!pic->pixels)
 		return;
-	src = (ulong *) pic->pixels;
+	src = (zlong *) pic->pixels;
 
 	x--;
 	y--;
@@ -647,8 +649,8 @@ void os_draw_picture(int picture, int y, int x)
 		for (yy = 0; yy < eh; yy++) {
 			for (xx = 0; xx < ew; xx++) {
 				dst =
-				    sbuffer + x + (uint32_t)(xx * m_gfxScale_w) +
-				    sbpitch * (y + (uint32_t)(yy * m_gfxScale_h));
+				    sbuffer + x + (zlong)(xx * m_gfxScale_w) +
+				    sbpitch * (y + (zlong)(yy * m_gfxScale_h));
 				sval = src[xx];
 				alpha = (sval >> 24);
 				if (alpha == 255)
@@ -670,10 +672,10 @@ void os_draw_picture(int picture, int y, int x)
 	}
 
 	dirty = 1;
-}
+} /* os_draw_picture */
 
 
-static ulong mytimeout;
+static zlong mytimeout;
 int mouse_button;
 static int numAltQ = 0;
 
@@ -683,7 +685,7 @@ static void set_mouse_xy(int x, int y)
 	 * SDL maps mouse events to logical coordinates. */
 	mouse_x = x + 1;
 	mouse_y = y + 1;
-}
+} /* set_mouse_xy */
 
 
 /**
@@ -713,7 +715,7 @@ static zword decode_utf8(char *str)
 		res |= (str[i] & 077);
 	}
 	return res;
-}
+} /* decode_utf8 */
 
 
 static void handle_window_event(SDL_Event * e)
@@ -722,7 +724,7 @@ static void handle_window_event(SDL_Event * e)
 	case SDL_WINDOWEVENT_EXPOSED:
 		myGrefresh();
 	}
-}
+} /* handle_window_event */
 
 
 static zword goodzkey(SDL_Event * e, int allowed)
@@ -738,7 +740,7 @@ static zword goodzkey(SDL_Event * e, int allowed)
 		if (true) {
 			mouse_button = e->button.button;
 			set_mouse_xy(e->button.x, e->button.y);
-			return ZC_SINGLE_CLICK;
+			return (e->button.clicks == 1 ? ZC_SINGLE_CLICK : ZC_DOUBLE_CLICK);
 		} else
 			return 0;
 	case SDL_KEYDOWN:
@@ -872,7 +874,7 @@ static zword goodzkey(SDL_Event * e, int allowed)
 		handle_window_event(e);
 	}
 	return 0;
-}
+} /* goodzkey */
 
 
 zword sf_read_key(int timeout, bool cursor, bool allowed, bool text)
@@ -911,7 +913,7 @@ zword sf_read_key(int timeout, bool cursor, bool allowed, bool text)
 		sf_drawcursor(false);
 
 	return inch;
-}
+} /* sf_read_key */
 
 
 /*
@@ -924,7 +926,7 @@ zword sf_read_key(int timeout, bool cursor, bool allowed, bool text)
 zchar os_read_key(int timeout, int cursor)
 {
 	return sf_read_key(timeout, cursor, false, true);
-}
+} /* os_read_key */
 
 
 /*
@@ -1116,7 +1118,6 @@ zchar os_read_line(int max, zchar * buf, int timeout, int width, int continued)
 				}
 				if (is_terminator(c)) {
 					/* Terminate the current input */
-					m_exitPause = false;
 					sf_DrawInput(buf, pos, ptx, pty, width,
 						     false);
 
@@ -1138,7 +1139,7 @@ zchar os_read_line(int max, zchar * buf, int timeout, int width, int continued)
 		sf_checksound();
 		sf_sleep(10);
 	}
-}
+} /* os_read_line */
 
 /* Draw the current input line */
 void sf_DrawInput(zchar * buffer, int pos, int ptx, int pty, int width,
@@ -1167,7 +1168,7 @@ void sf_DrawInput(zchar * buffer, int pos, int ptx, int pty, int width,
 
 	/* Update the window */
 	sf_flushdisplay();
-}
+} /* sf_DrawInput */
 
 
 /*
@@ -1180,7 +1181,7 @@ void sf_DrawInput(zchar * buffer, int pos, int ptx, int pty, int width,
  */
 zword os_read_mouse(void)
 {
-	byte c;
+	zbyte c;
 	int x, y;
 	zword btn = 0;
 	/* Get the mouse position */
@@ -1199,7 +1200,7 @@ zword os_read_mouse(void)
 		btn |= 4;
 
 	return btn;
-}
+} /* os_read_mouse */
 
 
 /*
@@ -1235,12 +1236,12 @@ void os_more_prompt(void)
 		/* Restore the current text position */
 		sf_poptextsettings();
 	}
-}
+} /* os_more_prompt */
 
 
-ulong *sf_savearea(int x, int y, int w, int h)
+zlong *sf_savearea(int x, int y, int w, int h)
 {
-	ulong *r, *p, *s;
+	zlong *r, *p, *s;
 	int i;
 
 	if (x < 0) {
@@ -1261,7 +1262,7 @@ ulong *sf_savearea(int x, int y, int w, int h)
 	if (h <= 0)
 		return NULL;
 
-	r = p = malloc((w * h + 4) * sizeof(ulong));
+	r = p = malloc((w * h + 4) * sizeof(zlong));
 	if (!r)
 		return NULL;
 
@@ -1272,17 +1273,17 @@ ulong *sf_savearea(int x, int y, int w, int h)
 
 	s = sbuffer + x + y * sbpitch;
 	for (i = 0; i < h; i++) {
-		memmove(p, s, w * sizeof(ulong));
+		memmove(p, s, w * sizeof(zlong));
 		p += w;
 		s += sbpitch;
 	}
 	return r;
-}
+} /* sf_savearea */
 
 
-void sf_restoreareaandfree(ulong * s)
+void sf_restoreareaandfree(zlong * s)
 {
-	ulong *p, *d;
+	zlong *p, *d;
 	int i, x, y, w, h;
 	if (!s)
 		return;
@@ -1295,7 +1296,7 @@ void sf_restoreareaandfree(ulong * s)
 
 	d = sbuffer + x + y * sbpitch;
 	for (i = 0; i < h; i++) {
-		memmove(d, p, w * sizeof(ulong));
+		memmove(d, p, w * sizeof(zlong));
 		p += w;
 		d += sbpitch;
 	}
@@ -1303,11 +1304,11 @@ void sf_restoreareaandfree(ulong * s)
 	free(s);
 	dirty = 1;
 	sf_flushdisplay();
-}
+} /* sf_restoreareaandfree */
 
 
 int (*sf_osdialog)(bool ex, const char *def, const char *filt, const char *tit,
-		   char **res, ulong * sbuf, int sbp, int ew, int eh,
+		   char **res, zlong * sbuf, int sbp, int ew, int eh,
 		   int isfull) = NULL;
 
 
@@ -1319,20 +1320,20 @@ int sf_user_fdialog(bool existing, const char *defaultname, const char *filter,
 				   sbuffer, sbpitch, ewidth, eheight,
 				   isfullscreen);
 	return SF_NOTIMP;
-}
+} /* sf_user_fdialog */
 
 
-void sf_videodata(ulong ** sb, int *sp, int *ew, int *eh)
+void sf_videodata(zlong ** sb, int *sp, int *ew, int *eh)
 {
 	*sb = sbuffer;
 	*sp = sbpitch;
 	*ew = ewidth;
 	*eh = eheight;
-}
+} /* sf_videodata */
 
 
 extern zword sf_yesnooverlay(int xc, int yc, char *t, int sr);
-static void sf_quitconf()
+static void sf_quitconf(void)
 {
 	if (sf_yesnooverlay(ewidth / 2, eheight / 2, "Quit: are you sure?", 1)
 	    == ZC_RETURN) {
@@ -1341,10 +1342,10 @@ static void sf_quitconf()
 		SDL_Quit();
 		os_quit(EXIT_SUCCESS);
 	}
-}
+} /* sf_quitconf */
 
 
-void os_tick()
+void os_tick(void)
 {
 	sf_checksound();
 	if (SDL_AtomicSet(&SFticked, 0)) {
@@ -1357,7 +1358,7 @@ void os_tick()
 				handle_window_event(&ev);
 		}
 	}
-}
+} /* os_tick */
 
 
 /* Apply the picture's palette to the screen palette. */
@@ -1367,7 +1368,7 @@ static bool ApplyPalette(sf_picture * graphic)
 	bool changed = FALSE;
 	int i, colors;
 
-	memset(&screen_palette, 0, sizeof(ulong));
+	memset(&screen_palette, 0, sizeof(zlong));
 
 	if (graphic->usespalette) {
 		colors = graphic->palette_entries;
@@ -1381,4 +1382,4 @@ static bool ApplyPalette(sf_picture * graphic)
 		}
 	}
 	return changed;
-}
+} /* ApplyPalette */
