@@ -42,7 +42,6 @@ x_setup_t x_setup;
 static int saved_argc;
 static char **saved_argv;
 static char *user_bg, *user_fg;
-static int user_tandy_bit;
 static int user_random_seed = -1;
 char *x_class;
 char *x_name;
@@ -50,13 +49,41 @@ char *x_name;
 
 static void print_c_string(const char *s)
 {
-	zchar c;
+	int i;
 
-	while ((c = *s++) != 0)
-		os_display_char(c);
+	for (i = 0; i <= strlen(s); i++)
+		os_display_char(translate_to_zscii(s[i]));
 } /* print_c_string */
 
 
+/*
+ * os_warn
+ *
+ * Display a warning message and continue with the game.
+ *
+ */
+void os_warn (const char *s, ...)
+{
+	va_list m;
+	char errorstring[81];
+	int style;
+
+	va_start(m, s);
+	vsnprintf(errorstring, sizeof(char) * 80, s, m);
+	va_end(m);
+
+	style = os_get_text_style();
+	os_beep(BEEP_HIGH);
+	os_set_text_style(BOLDFACE_STYLE);
+	print_c_string("Warning: ");
+	os_set_text_style(NORMAL_STYLE);
+	print_c_string(errorstring);
+	new_line();
+	os_set_text_style(style);
+	return;
+}
+
+
 /*
  * os_fatal
  *
@@ -66,13 +93,21 @@ static void print_c_string(const char *s)
 void os_fatal(const char *s, ...)
 {
 	va_list m;
+	char errorstring[81];
 
-	fprintf(stderr, "\nFatal Error: ");
+	os_beep(BEEP_HIGH);
+	fprintf(stderr, "\nFatal error: ");
 	va_start(m, s);
 	vfprintf(stderr, s, m);
-	print_c_string(s);
+	vsnprintf(errorstring, sizeof(char) * 80, s, m);
 	va_end(m);
-	fprintf(stderr, "\n");
+	fprintf(stderr, "\n\n");
+
+	os_set_text_style(BOLDFACE_STYLE);
+	print_c_string("Fatal error: ");
+	os_set_text_style(NORMAL_STYLE);
+	print_c_string(errorstring);
+	new_line();
 
 	if (f_setup.ignore_errors) {
 		os_display_string((zchar *) "Continuing anyway...");
@@ -80,8 +115,7 @@ void os_fatal(const char *s, ...)
 		new_line();
 	}
 
-	
-
+	os_reset_screen();
 	os_quit(EXIT_FAILURE);
 } /* os_fatal */
 
@@ -192,6 +226,7 @@ void os_process_arguments(int argc, char *argv[])
 		{"+e", ".ignoreErrors", XrmoptionNoArg, (void *)"false"},
 		{"-p", ".piracy", XrmoptionNoArg, (void *)"true"},
 		{"+p", ".piracy", XrmoptionNoArg, (void *)"false"},
+		{"-R", ".restricted", XrmoptionSepArg, (void *)NULL},
 		{"-t", ".tandy", XrmoptionNoArg, (void *)"true"},
 		{"+t", ".tandy", XrmoptionNoArg, (void *)"false"},
 		{"-u", ".undoSlots", XrmoptionSepArg, (void *)NULL},
@@ -210,7 +245,8 @@ void os_process_arguments(int argc, char *argv[])
 		{"-fn-fb", ".fontFB", XrmoptionSepArg, (void *)NULL},
 		{"-fn-fi", ".fontFI", XrmoptionSepArg, (void *)NULL},
 		{"-fn-fbi", ".fontFBI", XrmoptionSepArg, (void *)NULL},
-		{"-fn-z", ".fontZ", XrmoptionSepArg, (void *)NULL}
+		{"-fn-z", ".fontZ", XrmoptionSepArg, (void *)NULL},
+		{"-L", ".loadthis", XrmoptionSepArg, (void *)NULL}
 	};
 	static struct {
 		char *class;
@@ -236,8 +272,10 @@ void os_process_arguments(int argc, char *argv[])
 		 &f_setup.ignore_errors},
 		{".Piracy", ".piracy", parse_boolean,
 		 &f_setup.piracy},
+		{".Restricted", ".restricted", parse_string,
+		 &f_setup.restricted_path},
 		{".Tandy", ".tandy", parse_boolean,
-		 &x_setup.tandy_bit},
+		 &f_setup.tandy},
 		{".UndoSlots", ".undoSlots", parse_int,
 		 &f_setup.undo_slots},
 		{".ShowVersion", ".showVersion", parse_boolean,
@@ -271,7 +309,9 @@ void os_process_arguments(int argc, char *argv[])
 		{".Font", ".fontFBI", parse_string,
 		 &font_names[7]},
 		{".Font", ".fontZ", parse_string,
-		 &font_names[8]}
+		 &font_names[8]},
+		{".LoadThis", ".loadthis", parse_string,
+		 &f_setup.tmp_save_name}
 	};
 	XtAppContext app_context;
 	char *str_type_return;
@@ -312,7 +352,7 @@ void os_process_arguments(int argc, char *argv[])
 		printf("Git commit:     %s\n", GIT_HASH);
 		printf("Notes:          %s\n", RELEASE_NOTES);
 		printf("  Frotz was originally written by Stefan Jokisch.\n");
-		printf("  It complies with standard 1.0 of Graham Nelson's specification.\n");
+		printf("  It complies with standard 1.1 of the Z-Machine Standard.\n");
 		printf("  The X11 interface code was done by Daniel Schepler,\n");
 		printf("  It is distributed under the GNU General Public License version 2 or\n");
 		printf("    (at your option) any later version.\n");
@@ -329,6 +369,9 @@ void os_process_arguments(int argc, char *argv[])
 		os_quit(EXIT_SUCCESS);
 	}
 
+	if (f_setup.tmp_save_name != NULL)
+		f_setup.restore_mode = 1;
+
 	f_setup.story_file = strdup(argv[1]);
 	f_setup.story_name = strdup(basename(argv[1]));
 
@@ -372,7 +415,7 @@ void os_process_arguments(int argc, char *argv[])
 		memcpy(f_setup.save_name, f_setup.tmp_save_name,
 		       (strlen(f_setup.tmp_save_name) +
 			strlen(EXT_SAVE)) * sizeof(char));
-		free(f_setup.tmp_save_name);
+		/* No need to free f_setup.tmp_save_name */
 	}
 
 	f_setup.aux_name =
@@ -430,7 +473,7 @@ void os_init_screen(void)
 	XGCValues gc_setup;
 
 	/* First, configuration parameters get set up */
-	if (z_header.version == V3 && user_tandy_bit != 0)
+	if (z_header.version == V3 && f_setup.tandy != 0)
 		z_header.config |= CONFIG_TANDY;
 	if (z_header.version == V3)
 		z_header.config |= CONFIG_SPLITSCREEN | CONFIG_PROPORTIONAL;
@@ -446,10 +489,6 @@ void os_init_screen(void)
 		z_header.flags |= SOUND_FLAG;
 #endif
 	}
-	if (z_header.version >= V6) {
-		z_header.config |= CONFIG_PICTURES;
-		z_header.flags &= ~MENU_FLAG;
-	}
 
 	if (z_header.version >= V5 && (z_header.flags & UNDO_FLAG)
 	    && f_setup.undo_slots == 0)
@@ -554,8 +593,15 @@ void os_init_screen(void)
 	}
 	bgpm = XCreatePixmap(dpy, main_window, X_WIDTH, X_HEIGHT, DefaultDepth(dpy,DefaultScreen(dpy)));
 	XSetWindowBackgroundPixmap(dpy, main_window, bgpm);
-	x_init_pictures();
 
+	/* Must be after screen dimensions are computed.  */
+	if (z_header.version >= V6) {
+		if (x_init_pictures()) {
+			z_header.config |= CONFIG_PICTURES;
+			z_header.flags &= ~MENU_FLAG;
+		} else
+			z_header.flags &= ~GRAPHICS_FLAG;
+	}
 } /* os_init_screen */
 
 
@@ -628,6 +674,7 @@ int os_random_seed(void)
 
 void os_init_setup(void)
 {
+	memset(&f_setup, 0, sizeof(x_setup));
 	return;
 }
 
